@@ -21,21 +21,23 @@
 
 #define APP_NAME		"Tickr"
 #define APP_CMD			"tickr"
-#define APP_VERSION_NUMBER	"0.6.0"
-#define APP_WEBSITE		"http://www.newsrssticker.com"
-#define APP_SUPPORT_WEBSITE	"http://www.newsrssticker.com/help.php"
-#define APP_DOWNLOAD_WEBSITE	"http://www.newsrssticker.com/download.php"
-#define APP_SUPPORT_EMAIL	"tickrfeedreader@gmail.com"/*"contact@newsrssticker.com"*/
+#define APP_VERSION_NUMBER	"0.6.1"
+#define WEBSITE_URL		"http://www.newsrssticker.com"
+#define SUPPORT_URL		WEBSITE_URL"/help.php"
+#define DOWNLOAD_URL		WEBSITE_URL"/download.php"
+#define SUPPORT_EMAIL_ADDR	"manu@newsrssticker.com"
+#define CHECK4UPDATES_URL	WEBSITE_URL"/app_version_visible.php"
+#define CHECK4UPDATES_ID_STR	"LSVN="	/* Stands for 'Last Stable Version Number =' */
 
 #define _GNU_SOURCE
 #define _ISOC99_SOURCE
 
-/*#define WITHOUT_GTK_SPINNER*/		/* for karmic and jaunty */
+/*#define WITHOUT_GTK_SPINNER*/		/* For karmic and jaunty (now deprecated) */
 #define VERBOSE_OUTPUT
 /*#define DEBUG_OUTPUT*/
 
-/* for info_win_wait(..., timeout) */
-/*#define INFO_WIN_WAIT_POS	GTK_WIN_POS_CENTER*/	/* same as for info_win() */
+/* For info_win_wait(..., timeout) */
+/*#define INFO_WIN_WAIT_POS	GTK_WIN_POS_CENTER*/	/* Same as for info_win() */
 #define INFO_WIN_WAIT_POS	GTK_WIN_POS_CENTER_ON_PARENT
 /*#define INFO_WIN_WAIT_POS	GTK_WIN_POS_NONE*/
 #define INFO_WIN_WAIT_TIMEOUT	2000	/* in ms */
@@ -43,7 +45,7 @@
 #define CONNECT_FAIL_MAX	5
 #define CONNECT_FAIL_TIMEOUT	1
 
-/* for correctness, 'uri' should be used instead of 'url' */
+/* For correctness sake, 'uri' should be used instead of 'url'. */
 
 #include <stdio.h>
 #include <string.h>
@@ -64,7 +66,7 @@
 # include <arpa/inet.h>
 # include <sys/select.h>
 #else
-/* win version = xp or higher */
+/* Win version = XP or higher */
 # define WINVER		0x0501
 # define _WIN32_WINNT	0x0501
 # include <winsock2.h>
@@ -85,23 +87,13 @@
 #include "tickr_socket.h"
 #include "tickr_list.h"
 
-#define	USE_GUI			TRUE	/* to implement or not gui/menu features at compile time
-					 * otherwise, cli only app */
-#if USE_GUI
-# define RESOURCE_NONE_QUIT	FALSE	/* to quit or not if no resource id specified */
-# define OPTION_ERROR_QUIT	FALSE	/* to quit or not if unknown or invalid option(s) */
-#else
-# define RESOURCE_NONE_QUIT	TRUE
-# define OPTION_ERROR_QUIT	TRUE
-#endif
+#define RESOURCE_NONE_QUIT	FALSE	/* To quit or not if no resource is specified */
+#define OPTION_ERROR_QUIT	FALSE	/* To quit or not if unknown or invalid option(s) */
 
 #define DRWA_WIDTH_MIN		100
 #define DRWA_HEIGHT_MIN		10
 #define TAB_SIZE		8
-/* ok? previous value was FILE_NAME_MAXLEN = 255 - apply to both full file names and urls
- * maybe we should change this so that file name max len = 255 and url max len = 2047 (or more) */
-#define FILE_NAME_MAXLEN	(2 * 1024 - 1)
-/*#define URL_MAXLEN		(2 * 1024 - 1)*/	/* unused so far, see above */
+#define FILE_NAME_MAXLEN	(2 * 1024 - 1)	/* Apply to both FULL FILE NAMES and ***URLs*** */
 #define FONT_NAME_MAXLEN	64
 #define FONT_SIZE_MAXLEN	3
 #define FONT_MAXLEN		FONT_NAME_MAXLEN + 1 + FONT_SIZE_MAXLEN
@@ -109,11 +101,11 @@
 #define OPTION_NAME_MAXLEN	31
 #define OPTION_VALUE_MAXLEN	MAX(MAX(FILE_NAME_MAXLEN, FONT_MAXLEN), DELIMITER_MAXLEN)
 #define OPTION_MAXLEN		OPTION_NAME_MAXLEN + OPTION_VALUE_MAXLEN + 4	/* -name="value" */
-#define N_OPTION_MAX		64	/* max number of options */
-#define N_URL_MAX		1024	/* max number of url's */
-#define NFEEDLINKANDOFFSETMAX	256	/* max number of "open-able" links per feed */
+#define N_OPTION_MAX		64	/* Max number of options */
+#define N_URL_MAX		1024	/* Max number of url's */
+#define NFEEDLINKANDOFFSETMAX	256	/* Max number of "open-able" links per feed */
 #define LINK_TAG_CHAR		'^'	/* ascii 5E - char used internally for links, removed from feed text */
-#define TMPSTR_SIZE		(2 * 1024 - 1)	/* used for most tmp strings - must be large enough */
+#define TMPSTR_SIZE		(2 * 1024 - 1)	/* Used for most tmp strings - must be large enough */
 #ifndef G_OS_WIN32
 # define SEPARATOR_CHAR		'/'
 #else
@@ -128,26 +120,28 @@
 #define UNSELECTED_URL_CHAR	'-'
 #define UNSELECTED_URL_STR	"-"
 
-/* make sure this stuff is robust enough */
+/* Make sure this stuff is robust enough */
 #define XPIXMAP_MAXWIDTH	(32 * 1024 - 1)	/* 32 K - 1 = max supported width for xpixmaps
-						 * (not 64 k - 1 as sometimes uncorrectly specified)
+						 * (not 64 k - 1 as sometimes uncorrectly specified.)
 						 */
-#define LINE_MAXLEN		128	/* max length of a single line (see tickr_render.c) */
-#define WORD_MAXLEN		32	/* max length of a word that won't get cut off */
+#define LINE_MAXLEN		128	/* Max length of a single line (see tickr_render.c) */
+#define WORD_MAXLEN		32	/* Max length of a word that won't get cut off */
 #if (LINE_MAXLEN <= WORD_MAXLEN)
 # error LINE_MAXLEN must be > WORD_MAXLEN
 #endif
 #define FONT_MAXSIZE		200
 
+#define ARBITRARY_TASKBAR_HEIGHT 25
+
 /*
- * file names, paths and dirs stuff
+ * File names, paths and dirs stuff
  *
- * linux version:	/usr/bin/
+ * Linux version:	/usr/bin/
  *			/usr/share/APP_CMD/
  *			/usr/share/APP_CMD/pixmpas/
  *			/home/<user_name>/.APP_CMD/
  *
- * win32 version:	C:\Program files\APP_NAME\	(also location for pixmaps)
+ * Win32 version:	C:\Program files\APP_NAME\	(also location for pixmaps)
  *			C:\...\Application Data\APP_NAME\
  */
 #ifndef G_OS_WIN32
@@ -182,7 +176,7 @@
 #define TICKR_LOGO		APP_CMD"-logo.png"
 #define RSS_ICON		APP_CMD"-rss-icon.png"
 
-/* default config values */
+/* Default config values */
 #define DELAY			8
 #define SHIFTSIZE		1
 #ifndef G_OS_WIN32
@@ -191,14 +185,14 @@
 # define FONTNAME		"Arial Unicode MS"
 #endif
 #define FONTSIZE		"14"
-#define FGCOLOR			"#ffffffff"	/* white */
-#define BGCOLOR			"#36516240"	/* some translucent blue */
+#define FGCOLOR			"#ffffffff"	/* White */
+#define BGCOLOR			"#36516240"	/* Some translucent blue */
 #define WIN_X			0
 #define WIN_Y			0
-#define WIN_W			1024	/* unused, we use get_ticker_env()->screen_w instead */
-#define WIN_H			0	/* if = 0, determined by font size */
+#define WIN_W			1024	/* Unused, we use get_ticker_env()->screen_w instead */
+#define WIN_H			0	/* If = 0, determined by font size */
 #define WINDEC			'n'
-#define ALWAYSONTOP		'y'
+#define ALWAYSONTOP		'n'	/* Changed to no */
 #ifndef G_OS_WIN32
 # define WINTRANSPARENCY	1.0
 #else
@@ -212,17 +206,22 @@
 #define SHADOWFX		2
 #define LINEDELIMITER		" "
 #define CUTLINEDELIMITER	"..."LINEDELIMITER
+#define SPECIALCHARS		'n'
+#define NEWPG			'`'
+#define TABCH			'~'
 #define RSSREFRESH		15
-#define RSSTITLE		'y'
-#define RSSTITLEDELIMITER	"        "
-#define RSSDESCRIPTION		'n'
-#define RSSDESCRIPTIONDELIMITER	"        -        "
+#define FEEDTITLE		'n'
+#define FEEDTITLEDELIMITER	"        "
+#define ITEMTITLE		'y'
+#define ITEMTITLEDELIMITER	"        "
+#define ITEMDESCRIPTION		'n'
+#define ITEMDESCRIPTIONDELIMITER "        -        "
 #define NITEMSPERFEED		5
 #define STRIPHTMLTAGS		'y'
 #define UPPERCASETEXT		'n'
 #define HOMEFEED		"http://newsrss.bbc.co.uk/rss/newsonline_world_edition/front_page/rss.xml"
 #ifndef G_OS_WIN32
-# define OPENLINKCMD		"firefox"	/* firefox on linux */
+# define OPENLINKCMD		"firefox"	/* Firefox on Linux */
 #else
 # define OPENLINKCMD		""
 #endif
@@ -234,10 +233,8 @@
 #define CBGCOLOR		BGCOLOR
 #define DISABLEPOPUPS		'n'
 #define PAUSEONMOUSEOVER	'y'
+#define DISABLELEFTCLICK	'n'
 #define MOUSEWHEELSCROLL	's'
-#define SPECIALCHARS		'n'
-#define NEWPG			'`'
-#define TABCH			'~'
 #define USEAUTHENTICATION	'n'
 #define USER			""
 #define USEPROXY		'n'
@@ -246,6 +243,11 @@
 #define USEPROXYAUTHENTICATION	'n'
 #define PROXYUSER		""
 
+/* Global pseudo stdout and stderr on win32 */
+#ifdef G_OS_WIN32
+extern FILE	*stdout_fp, *stderr_fp;
+#endif
+
 /* typedef enum's */
 typedef enum {
 	SINGLE,
@@ -255,8 +257,8 @@ typedef enum {
 typedef enum {
 	RESRC_TYPE_UNDETERMINED,
 	RESRC_UNSPECIFIED,
-	RESRC_URL,		/* will be fetched and xml-parsed */
-	RESRC_FILE		/* will be processed as non-xml text file */
+	RESRC_URL,		/* Will be fetched and xml-parsed */
+	RESRC_FILE		/* Will be processed as non-xml text file */
 } _resrc_type;
 
 typedef enum {
@@ -294,26 +296,26 @@ typedef enum {
 } connection_settings_page;
 
 /* typedef struct's */
-/* usefull graphical (and other) ticker 'environment' values */
+/* Usefull graphical (and other) ticker 'environment' values */
 typedef struct {
-	GdkScreen	*screen;			/* gdk screen for win */
+	GdkScreen	*screen;			/* GDK screen for win */
 	GdkVisual	*visual;
-	gint		screen_w, screen_h;		/* screen width & height */
-	gint		depth;				/* screen depth */
-	GtkWidget 	*win;				/* top level window */
-	GtkWidget	*drw_a, *drwa_clock;		/* drawing areas (main / clock) */
-	gint		drwa_width, drwa_height;	/* main drawing area dimensions */
-	gint		drwa_clock_width;		/* clock drawing area width */
-	cairo_surface_t	*c_surf;			/* cairo image surface onto which text is rendered */
-	gint 		surf_width, surf_height;	/* cairo image surface dimensions */
+	gint		screen_w, screen_h;		/* Screen width & height */
+	gint		depth;				/* Screen depth */
+	GtkWidget 	*win;				/* Top level window */
+	GtkWidget	*drw_a, *drwa_clock;		/* Drawing areas (main / clock) */
+	gint		drwa_width, drwa_height;	/* Main drawing area dimensions */
+	gint		drwa_clock_width;		/* Clock drawing area width */
+	cairo_surface_t	*c_surf;			/* Cairo image surface onto which text is rendered */
+	gint 		surf_width, surf_height;	/* Cairo image surface dimensions */
 	char		active_link[FILE_NAME_MAXLEN + 1];
-	/* these flags are checked by callback */
-	gboolean	suspend_rq;			/* request for doing nothing */
-	gboolean	compute_rq;			/* request for (re)computing everything (surface and win) */
-	gboolean	reload_rq;			/* request for (re)loading resource */
-	_selection_mode	selection_mode;			/* default = MULTIPLE, set to SINGLE internally if selection
+	/* These flags are checked by callback */
+	gboolean	suspend_rq;			/* Request for doing nothing */
+	gboolean	compute_rq;			/* Request for (re)computing everything (surface and win) */
+	gboolean	reload_rq;			/* Request for (re)loading resource */
+	_selection_mode	selection_mode;		/* default = MULTIPLE, set to SINGLE internally if selection
 							 * is unavalaible/empty or after picking a single feed */
-	gboolean	stream_fully_read;		/* set/checked only in render_stream_to_surface() and
+	gboolean	stream_fully_read;		/* Set/checked only in render_stream_to_surface() and
 							 * shift2left_callback() */
 } TickerEnv;
 
@@ -323,15 +325,15 @@ typedef struct {
 } FeedLinkAndOffset;
 
 typedef struct {
-	_resrc_type	type;				/* text file or url */
+	_resrc_type	type;				/* Text file or url */
 	_rss_format	format;				/* RSS 1.0, RSS 2.0 or Atom */
-	char		id[FILE_NAME_MAXLEN + 1];	/* local = file name or remote = feed url */
-	/* apply only to url/rss */
+	char		id[FILE_NAME_MAXLEN + 1];	/* Local = file name or remote = feed url */
+	/* Apply only to url/rss */
 	_rss_format	rss_format;
 	char		feed_title[FEED_TITLE_MAXLEN + 1];
-	char		resrc_dump[FILE_NAME_MAXLEN + 1];	/* downloaded file/resource */
+	char		resrc_dump[FILE_NAME_MAXLEN + 1];	/* Downloaded file/resource */
 	char		xml_dump[FILE_NAME_MAXLEN + 1];
-	FILE		*fp;				/* file to be read (from xmldump) after some processing, */
+	FILE		*fp;				/* File to be read (from xmldump) after some processing, */
 	FeedLinkAndOffset link_and_offset[NFEEDLINKANDOFFSETMAX];
 	int		rss_ttl;
 } Resource;
@@ -340,7 +342,7 @@ typedef struct {
 #define PSW_MAXLEN		63
 #define AUTH_STR_MAXLEN		127
 
-/* do we need both these auth/proxy structs and auth/proxy params? redundant... */
+/* Do we need both these auth/proxy structs and auth/proxy params? redundant... */
 typedef struct {
 	gboolean	use_authentication;
 	char		user[USER_MAXLEN + 1];
@@ -389,11 +391,16 @@ typedef struct {
 	int		shadow_fx;
 	char		line_delimiter[DELIMITER_MAXLEN + 1];
 	char		cutline_delimiter[DELIMITER_MAXLEN + 1];
+	char		special_chars;
+	char		new_page_char;
+	char		tab_char;
 	int		rss_refresh;
-	char		rss_title;
-	char		rss_title_delimiter[DELIMITER_MAXLEN + 1];
-	char		rss_description;
-	char		rss_description_delimiter[DELIMITER_MAXLEN + 1];
+	char		feed_title;
+	char		feed_title_delimiter[DELIMITER_MAXLEN + 1];
+	char		item_title;
+	char		item_title_delimiter[DELIMITER_MAXLEN + 1];
+	char		item_description;
+	char		item_description_delimiter[DELIMITER_MAXLEN + 1];
 	int		n_items_per_feed;
 	char		strip_html_tags;
 	char		upper_case_text;
@@ -408,11 +415,9 @@ typedef struct {
 	guint16		clock_bg_color_alpha;
 	char		disable_popups;
 	char		pause_on_mouseover;
-	char		mouse_wheel_scroll;	/* apply to s (speed) / f (feed) / n (none) */
-	char		special_chars;
-	char		new_page_char;
-	char		tab_char;
-/* do we need both these auth/proxy structs and auth/proxy params? redundant... */
+	char		disable_leftclick;
+	char		mouse_wheel_scroll;	/* Apply to s (speed) / f (feed) / n (none) */
+/* Do we need both these auth/proxy structs and auth/proxy params? redundant... */
 	char		use_authentication;
 	char		user[USER_MAXLEN + 1];
 	char		use_proxy;
@@ -422,7 +427,7 @@ typedef struct {
 	char		proxy_user[PROXY_USER_MAXLEN + 1];
 } Params;
 
-/* error codes */
+/* Error codes */
 typedef enum {
 	OK = SOCKET_LASTERRORCODE + 1,
 
@@ -579,6 +584,8 @@ void		get_new_url(Resource *);
 int		modify_params(Params *);
 
 /* tickr_otherwins.c */
+gint		esc_key_pressed(GtkWidget *, GdkEventKey *);
+void		force_quit_dialog(GtkWidget *);
 void		open_new_txt_file(Resource *resrc);
 void		help_win();
 void		about_win();
@@ -597,9 +604,7 @@ void		warning(gboolean, int, ...);
 void		dump_font_list();
 
 /* tickr_hlptxt.c */
-#if USE_GUI
 const char	**get_help_str0();
-#endif
 const char	**get_help_str1();
 const char	**get_license_str1();
 const char	*get_license_str2();
@@ -614,6 +619,7 @@ char		*create_opml_str_from_feed_list_node(FList *);
 int		save_str_as_opml_file(const char *);
 
 /* tickr_http.c */
+void		remove_chunk_info(char **);
 int		connect_with_url(sockt *, char *);
 int		fetch_resource(const char *, const char *, char *);
 const char	*build_http_request(const char *, const char *, const char *,\
@@ -630,7 +636,7 @@ const char	*get_host_from_url(const char*);
 const char	*get_path_from_url(const char*);
 
 /* tickr_socket.c */
-/* proto moved into tickr_socket.h */
+/* Proto moved into tickr_socket.h */
 
 /* tickr_connectwin.c */
 void		init_authentication();
@@ -655,4 +661,10 @@ char		*get_proxy_auth_str();
 
 /* tickr_quickfeedpicker.c */
 void		quick_feed_picker(int);
+
+/* tickr_quicksetup.c */
+void		quick_setup(Params *);
+
+/* tickr_check4updates.c */
+void		check_for_updates();
 #endif /* INC_TICKR_H */
