@@ -18,11 +18,7 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
-#define TIME_STR		"|%c%c:%c%c:%c%c"	/* at right = "|00:00:00" */
+#define TIME_STR		"|%c%c:%c%c:%c%c"	/* At right = "|00:00:00" */
 #define TIME_STR_LENGTH		9
 
 void display_time(const Params *prm)
@@ -62,22 +58,22 @@ void display_time(const Params *prm)
 
 		env->drwa_clock_width = get_clock_width(prm);	/* v_diff */
 		/*
-		 * for some fonts like 'impact bold' which give strange things
+		 * For some fonts like 'impact bold' which give strange things
 		 * v_diff = drwa_clock_width - layout_width;
 		 */
 		gtk_widget_set_size_request(env->drwa_clock, env->drwa_clock_width, env->drwa_height);
 		h_diff = (env->drwa_height - (gint)layout_height) / 2;
 		/*
-		 * create cairo image surface onto which layout will be rendered
+		 * Create cairo image surface onto which layout will be rendered
 		 */
 		surf_clock = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
 			env->drwa_clock_width, env->drwa_height);
 		cr = cairo_create(surf_clock);
 		/*
-		 * render layout
+		 * Render layout
 		 * (are used cairo operators ok ?)
 		 */
-		/* draw background */
+		/* Draw background */
 		cairo_set_source_rgba(cr,
 			(float)prm->clock_bg_color.red / G_MAXUINT16,
 			(float)prm->clock_bg_color.green / G_MAXUINT16,
@@ -86,9 +82,9 @@ void display_time(const Params *prm)
 			);
 		cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 		cairo_paint(cr);
-		/* draw foreground */
+		/* Draw foreground */
 		if (prm->shadow == 'y') {
-			/* draw shadow */
+			/* Draw shadow */
 			if (prm->shadow_fx < 0)
 				shadow_k = 1.0;
 			else if (prm->shadow_fx > 10)
@@ -105,7 +101,7 @@ void display_time(const Params *prm)
 			cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 			pango_cairo_show_layout(cr, p_layout);
 		}
-		/* draw text */
+		/* Draw text */
 		cairo_set_source_rgba(cr,
 			(float)prm->clock_fg_color.red / G_MAXUINT16,
 			(float)prm->clock_fg_color.green / G_MAXUINT16,
@@ -115,11 +111,11 @@ void display_time(const Params *prm)
 		cairo_move_to(cr, 0, 0);
 		cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 		pango_cairo_show_layout(cr, p_layout);
-		/* drawing done */
+		/* Drawing done */
 		if (p_layout != NULL)
 			g_object_unref(p_layout);
 		cairo_destroy(cr);
-		/* draw onto clock area
+		/* Draw onto clock area
 		 * (we now use cairo instead of deprecated gdk_draw_sth)
 		 */
 		cr = gdk_cairo_create(GDK_DRAWABLE((env->drwa_clock)->window));
@@ -132,7 +128,7 @@ void display_time(const Params *prm)
 	}
 }
 
-/* actually clock max width */
+/* Actually clock max width */
 gint get_clock_width(const Params *prm)
 {
 	static char		clock_font_n_s_bak[FONT_MAXLEN + 1] = "";
@@ -168,6 +164,6 @@ gint get_clock_width(const Params *prm)
 			width = (gint)layout_max_width;
 		}
 	} else
-		width = 0;	/* return 0 although if clock = none, actual widget width = 1 */
+		width = 0;	/* Return 0 although if clock = none, actual widget width = 1 */
 	return width;
 }
