@@ -18,10 +18,6 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
 static Authentication	*auth;
 static Proxy		*proxy;
 
@@ -54,7 +50,6 @@ void init_proxy()
 	proxy->auth_str[0] = '\0';
 }
 
-#if USE_GUI
 static gint enter_key_pressed_in_entry(GtkWidget *widget)
 {
 	widget = widget;
@@ -108,7 +103,6 @@ static gint check_but3_toggled(GtkWidget *check_button)
 	set_entries_sensitive3(proxy->use_proxy && proxy->use_proxy_authentication);
 	return TRUE;
 }
-#endif
 
 void compute_auth_and_proxy_str()
 {
@@ -148,19 +142,16 @@ void compute_auth_and_proxy_str()
 		proxy->auth_str[0] = '\0';
 }
 
-#if USE_GUI
-/* must be initialized with init_authentication() and init_proxy() */
+/* Must be initialized with init_authentication() and init_proxy() */
 gint connection_settings(connection_settings_page page)
 {
 	GtkWidget	*notebook, *table1, *table2, *hbox;
 	int		response = GTK_RESPONSE_CANCEL;
 
-	if (get_params()->disable_popups == 'y')	/* IS THIS ANY */
-		return GTK_RESPONSE_CANCEL;		/* BETTER? */
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 	dialog = gtk_dialog_new_with_buttons(
-			APP_NAME" Connection Settings", GTK_WINDOW(get_ticker_env()->win),
+			"Connection Settings", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
@@ -168,8 +159,9 @@ gint connection_settings(connection_settings_page page)
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 	/*
-	 * fill structs from params
+	 * Fill structs from params
 	 */
 	auth->use_authentication = (get_params()->use_authentication == 'y') ? TRUE : FALSE;
 	str_n_cpy(proxy->user, get_params()->user, USER_MAXLEN);
@@ -291,7 +283,7 @@ gint connection_settings(connection_settings_page page)
 	get_ticker_env()->suspend_rq = TRUE;
 	if ((response = gtk_dialog_run(GTK_DIALOG(dialog))) == GTK_RESPONSE_OK) {
 		/*
-		 * configure authentication
+		 * Configure authentication
 		 */
 		auth->use_authentication = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_but1));
 		str_n_cpy(auth->user, (char *)gtk_entry_get_text(GTK_ENTRY(entry_user)), USER_MAXLEN);
@@ -299,7 +291,7 @@ gint connection_settings(connection_settings_page page)
 		str_n_cpy(auth->psw, (char *)gtk_entry_get_text(GTK_ENTRY(entry_psw)), PSW_MAXLEN);
 		remove_char_from_str(auth->psw, ' ');
 		/*
-		 * configure proxy
+		 * Configure proxy
 		 */
 		proxy->use_proxy = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_but2));
 		str_n_cpy(proxy->host, (char *)gtk_entry_get_text(GTK_ENTRY(entry_host)), PROXY_HOST_MAXLEN);
@@ -307,7 +299,7 @@ gint connection_settings(connection_settings_page page)
 		str_n_cpy(proxy->port, (char *)gtk_entry_get_text(GTK_ENTRY(entry_port)), PROXY_PORT_MAXLEN);
 		remove_char_from_str(proxy->port, ' ');
 		/*
-		 * configure proxy authentication
+		 * Configure proxy authentication
 		 */
 		proxy->use_proxy_authentication = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(check_but3));
 		str_n_cpy(proxy->user, (char *)gtk_entry_get_text(GTK_ENTRY(entry_proxy_user)), PROXY_USER_MAXLEN);
@@ -315,11 +307,11 @@ gint connection_settings(connection_settings_page page)
 		str_n_cpy(proxy->psw, (char *)gtk_entry_get_text(GTK_ENTRY(entry_proxy_psw)), PROXY_PSW_MAXLEN);
 		remove_char_from_str(proxy->psw, ' ');
 		/*
-		 * compute auth and proxy stuff
+		 * Compute auth and proxy stuff
 		 */
 		compute_auth_and_proxy_str();
 		/*
-		 * save structs as params then to file
+		 * Save structs as params, then to file
 		 */
 		get_params()->use_authentication = auth->use_authentication ? 'y' : 'n';
 		str_n_cpy(get_params()->user, auth->user, USER_MAXLEN);
@@ -335,7 +327,6 @@ gint connection_settings(connection_settings_page page)
 	get_ticker_env()->suspend_rq = FALSE;
 	return response;
 }
-#endif
 
 gboolean get_use_authentication()
 {
