@@ -18,62 +18,67 @@
 
 #include "tickr.h"
 
-#if USE_GUI
 static const char *help_str0[] = {
-"USER INTERFACE MAIN FEATURES: \n\n",
+"USER INTERFACE MAIN FEATURES:\n\n",
 
-"- To open the main menu, right-click inside the ticker area.\n\n",
+"- To open the main menu, right-click inside ticker area.\n\n",
 
-"- To open a link in your Browser, left-click on the text.\n\n",
+"- You can import feed subscriptions with 'File > Import Feed List (OPML)',\n",
+"for instance your Google Reader subscriptions.\n\n",
 
-"Basically, you will use 'File > Open Feed (RSS|Atom)' to choose a feed from a list\n",
-"or to subscribe to a new one and 'Edit > Preferences' to tweak the ticker\n",
-"appearance as well as other settings.\n\n",
+"- To open a link in your browser, left-click on text.\n\n",
+
+"- Use mouse wheel to either adjust the ticker scrolling speed or open the\n",
+"'Selected Feed Picker' window to quickly move between selected feeds (if set,\n",
+"Ctrl + mouse wheel scrolling applies to other value.)\n",
+"This behaviour is set in the 'Preferences' window as 'Mouse wheel scrolling\n",
+"applies to'.\n\n",
+
+"- Basically, you will use 'File > Open RSS Feed' to choose a feed from a\n",
+"list, subscribe to a new one, manage your feed list, and 'Edit > Preferences'\n",
+"to tweak the ticker appearance as well as other settings.\n\n",
+
+"- 'Window - always on top' -> check this if you want the ticker to always\n",
+"stay above your browser (and any other windows.)\n\n",
+
+"- 'Window - decorated' -> if you want a 'draggable' ticker.\n\n",
+
+"There is a sample list of already subscribed feeds that you can use.\n\n",
 
 "***ONLY*** in case you're using the ticker inside a ***decorated*** window,\n",
-"you can use keyboard shortcuts:\n\n",
+"you can use these keyboard shortcuts:\n\n",
 
-"- <Ctrl>R to open the Feed Picker window (to choose a feed or to\n",
-"  subscribe to a new one.)\n\n",
+"- <Ctrl>R to open the 'RSS Feed Picker' window (to choose a feed or to\n",
+"subscribe to a new one.)\n\n",
 
 "- <Ctrl>T to open a text file.\n\n",
 
-"- <Ctrl>I to import feed list in OPML format.\n\n",
+"- <Ctrl>I to import (and merge) an URL list from an OPML file.\n\n",
 
-"- <Ctrl>E to export feed list in OPML format.\n\n",
+"- <Ctrl>E to export the URL list to an OPML file.\n\n",
 
-"- <Ctrl>P to open the Resource Properties window.\n\n",
+"- <Ctrl>P to open the 'Resource Properties' window.\n\n",
 
 "- <Ctrl>Q to quit.\n\n",
 
-"- <Ctrl>S to open the Preferences (settings) window.\n\n",
+"- <Ctrl>S to open the 'Preferences' (Settings) window.\n\n",
 
 "- <Ctrl>B to open the link displayed inside the ticker (in the middle.)\n\n",
 
 "- <Ctrl>J to play the feed / <Ctrl>K to pause / <Ctrl>L to reload.\n\n",
 
-"- <Ctrl>U (speed Up) / <Ctrl>D (speed Down) to adjust scrolling speed on\n",
-"  the fly.\n\n",
+"- <Ctrl>U (speed Up) / <Ctrl>D (speed Down) to adjust tscrolling speed on\n",
+"the fly.\n\n",
 
-"- F1 to open the Quick Help window.\n\n",
+"- F1 to open the 'Quick Help' window.\n\n",
 
-"- <Ctrl>H to launch the Online Help.\n\n",
-
-"- <Ctrl>A to open the About window and the License window.\n\n",
-
-"After install, you can set up 2 quite useful parameters in the\n",
-"Preferences window (<Ctrl>P):\n\n",
-
-"- Window - always on top -> uncheck this if you don't want the ticker\n",
-"  to always stay above the browser (and the other windows.)\n\n",
-
-"- Window - decorated -> convenient if you want a 'draggable' ticker.\n\n\n",
+"- <Ctrl>H to launch the 'Online Help' (this very page.)\n\n",
 
+"- <Ctrl>A to open the 'About' window and the License window.\n\n\n",
 
 "COMMAND LINE REFERENCE:\n\n",
 
 NULL};
-#endif
 
 static const char *help_str1[] = {
 	APP_NAME"-"APP_VERSION_NUMBER" - GTK-based highly graphically-customizable Feed Ticker\n",
@@ -82,7 +87,7 @@ static const char *help_str1[] = {
 	"scrolling line on your Desktop, as known from TV stations. Open feed\n"
 	"links in your favourite Browser. Graphics are highly customizable.\n\n"
 	"Usage:\n",
-	"        "APP_CMD" [-help / -version / -license / -instance-id=n / -dumpfontlist]\n",
+	"        "APP_CMD" [-help/-version/-license/-instance-id=n/-no-ui/-dumpfontlist]\n",
 	"              [options (-name[=value])...] [resource (file name or URL)]\n\n",
 	"        help                           Get this help page\n\n",
 	"        version                        Print out version number\n\n",
@@ -92,6 +97,9 @@ static const char *help_str1[] = {
 	"                                       instance using its own config and dump\n",
 	"                                       files (to be effective, instance-id must\n",
 	"                                       be the 1st argument)\n\n",
+	"        no-ui                          Disable opening of UI elements which can\n",
+	"                                       modify settings and/or URL list/\n",
+	"                                       selection\n\n",
 	"        dumpfontlist                   Send list of available fonts to stdout\n\n",
 	"Options:\n",
 	"        delay=n                        Delay in milliseconds\n\n",
@@ -116,12 +124,20 @@ static const char *help_str1[] = {
 	"        shadowfx=n                     Shadow effect (0 = none -> 10 = full)\n\n",
 	"        linedelimiter='str'            String to be appended at end of line\n\n",
 	"        cutlinedelimiter='str'         String to be appended after a cut line\n\n",
+	"        specialchars=[y/n]             Enable or disable special characters.\n",
+	"                                       This is only useful when resource is a\n",
+	"                                       file, not an URL\n\n",
+	"        newpgchar=c                    'New page' special character\n\n",
+	"        tabchar=c                      'Tab' (8 spaces) special character\n\n",
 	"        rssrefresh=n                   Refresh rate in minutes (if no TTL\n",
 	"                                       inside feed / always applies for files)\n\n",
-	"        rsstitle=[y/n]                 Show or hide title\n\n",
-	"        rsstitledelimiter='str'        String to be appended after title\n\n",
-	"        rssdescription=[y/n]           Show or hide description\n\n",
-	"        rssdescriptiondelimiter='str'  String to be appended after description\n\n",
+	"        feedtitle=[y/n]                Show or hide feed title\n\n",
+	"        feedtitledelimiter='str'       String to be appended after feed title\n\n",
+	"        itemtitle=[y/n]                Show or hide item title\n\n",
+	"        itemtitledelimiter='str'       String to be appended after item title\n\n",
+	"        itemdescription=[y/n]          Show or hide item description\n\n",
+	"        itemdescriptiondelimiter='str' String to be appended after item\n",
+	"                                       description\n\n",
 	"        nitemsperfeed=n                Read N items max per feed\n\n",
 	"        rmtags=[y/n]                   Strip html tags\n\n",
 	"        uppercasetext=[y/n]            Set all text to upper case\n\n",
@@ -141,13 +157,11 @@ static const char *help_str1[] = {
 	"        clockbgcolor=#rrggbbaa         Clock background 32-bit hexa color\n\n",
 	"        disablepopups=[y/n]            Disable error/warning popup windows\n\n",
 	"        pauseonmouseover=[y/n]         Pause ticker on mouseover\n\n",
-	"        mousewheelscroll=[s/f/n]       Mouse wheel scrolling apply to:\n",
-	"                                       (ticker-)speed / feed(-in-list) / none\n\n",
-	"        specialchars=[y/n]             Enable or disable special characters.\n",
-	"                                       This is only useful when resource is a\n",
-	"                                       file, not an URL\n\n",
-	"        newpgchar=c                    'new page' special character\n\n",
-	"        tabchar=c                      'tab' (8 spaces) special character\n\n",
+	"        disableleftclick=[y/n]         Disable left-click\n\n",
+	"        mousewheelscroll=[s/f/n]       Mouse wheel scrolling applies to:\n",
+	"                                       (ticker-)speed / feed(-in-list) / none\n",
+	"                                       (if set, Ctrl + mouse wheel scrolling\n",
+	"                                       applies to other value)\n\n",
 	"        useauth=[y/n]                  Use HTTP basic authentication\n\n",
 	"        user='str'                     User\n\n",
 	"        psw='str'                      Password (never saved)\n\n",
@@ -157,12 +171,16 @@ static const char *help_str1[] = {
 	"        useproxyauth=[y/n]             Use proxy authentication\n\n",
 	"        proxyuser='str'                Proxy user\n\n",
 	"        proxypsw='str'                 Proxy password (never saved)\n\n",
+	"Mouse usage:\n"
+	"        To open the main menu, right-click inside ticker area.\n\n",
+	"        You can import feed subscriptions from another feed reader with\n",
+	"        'File > Import Feed List (OPML)'.\n\n",
+	"        To open a link in your browser, left-click on text.\n\n",
+	"        Use mouse wheel to either adjust ticker scrolling speed or open the\n",
+	"        'Selected Feed Picker' window to quickly move between selected feeds\n",
+	"        (and use Ctrl + mouse wheel for the other option.)\n\n",
 	"The default browser is Firefox on Linux. You may change this setting to your\n",
 	"favourite one in the Preferences window.\n\n",
-	"You can open a link by clicking the text inside the ticker. Alternatively, with\n",
-	"a decorated window, you can type <Ctrl>B. When doing so, be aware that the link\n",
-	"to be open will be the one related to the text located in the middle of the\n",
-	"ticker area.\n\n",
 	APP_NAME" parses command line arguments and looks for option(s) then for one\n",
 	"resource, the rest of the line is ignored. It reads too configuration file\n",
 #ifndef G_OS_WIN32
@@ -175,7 +193,7 @@ static const char *help_str1[] = {
 	"Command line options override configuration file ones which override default\n",
 	"ones.\n\n",
 	"Compiled with GTK+ and Libxml2 on "__DATE__" - "__TIME__"\n",
-	"\nVisit "APP_WEBSITE" for more info.\n",
+	"\nVisit "WEBSITE_URL" for more info.\n",
 	NULL};
 
 static const char *license_str1[] = {
@@ -195,12 +213,10 @@ static const char *license_str1[] = {
 static const char *license_str2 =
 	"http://www.gnu.org/licenses/\n";
 
-#if USE_GUI
 const char** get_help_str0()
 {
 	return help_str0;
 }
-#endif
 
 const char** get_help_str1()
 {
