@@ -18,11 +18,7 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
-/* are these values ok? */
+/* Are these values OK ? */
 #define HTTP_REQUEST_MAXLEN		(8 * 1024 - 1)
 #define HTTP_HEADER_FIELD_MAXLEN	(2 * 1024 - 1)
 #define MAX_HTTP_REDIRECT		8
@@ -32,9 +28,9 @@ extern FILE	*stdout_fp, *stderr_fp;
 #define TAB				'\x09'
 
 /* S_MOD -> true in multiple selection mode / false otherwise */
-#define S_MOD		(get_ticker_env()->selection_mode == MULTIPLE)
+#define S_MOD	(get_ticker_env()->selection_mode == MULTIPLE)
 
-static void remove_chunk_info(char **response)
+void remove_chunk_info(char **response)
 {
 	char	*response2;
 	int	i, j;
@@ -52,13 +48,13 @@ static void remove_chunk_info(char **response)
 	*response = response2;
 }
 
-/* 'quickly check feed format' (xml/rss2.0/atom), get shift to beginnig
- * and cut off trailing part */
+/* 'Quickly check feed format' (xml/rss2.0/atom), get shift to beginnig
+ * and cut off trailing part. */
 static int format_quick_check(char *response, int *shift)
 {
 	int	i;
 
-	/* this may return false positives so disabled
+	/* This may return false positives so disabled
 	if (strcmp(get_http_header_value("Content-Type", response), "text/xml") != 0)
 		return FEED_FORMAT_ERROR;*/
 	i = 0;
@@ -95,7 +91,7 @@ static int format_quick_check(char *response, int *shift)
 	return OK;
 }
 
-/* get host from url but if connecting through proxy */
+/* Get host from url but if connecting through proxy */
 int connect_with_url(sockt *sock, char *url)
 {
 	char		host[FILE_NAME_MAXLEN + 1];
@@ -112,7 +108,7 @@ int connect_with_url(sockt *sock, char *url)
 			warning(S_MOD, 2, url, ":\nHTTPS protocol not currently supported");
 			return HTTP_UNSUPPORTED_SCHEME;
 		} else if (strcmp(get_scheme_from_url(url), "file") == 0)
-			;/* do nothing here */
+			;/* Do nothing here */
 		else if (get_scheme_from_url(url)[0] == '\0') {
 			warning(S_MOD, 2, "No scheme found in URL: ", url);
 			return HTTP_UNSUPPORTED_SCHEME;
@@ -122,7 +118,7 @@ int connect_with_url(sockt *sock, char *url)
 			return HTTP_UNSUPPORTED_SCHEME;
 		}
 	} else {
-		/* connect via proxy */
+		/* Connect via proxy */
 		str_n_cpy(host, get_proxy_host(), FILE_NAME_MAXLEN);
 		str_n_cpy(port_num, get_proxy_port(), PORT_STR_MAXLEN);
 	}
@@ -148,10 +144,10 @@ int connect_with_url(sockt *sock, char *url)
 }
 
 /* ***********************************
- *   TODO: DOCUMENT BETTER THIS FUNC
+ *   TODO: BETTER DOCUMENT THIS FUNC
  * ***********************************/
-/* we replace resrc->id with modified url and file_name = downloaded resource
- * maxlen of file_name, url, new_url = FILE_NAME_MAXLEN */
+/* We replace resrc->id with modified url and file_name = downloaded resource.
+ * Max length of file_name, url, and new_url = FILE_NAME_MAXLEN. */
 int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 {
 	sockt	sock;
@@ -225,8 +221,8 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 	} else
 		return i;
 	while (TRUE) {
-		/* status checked here are those returned by get_http_response()
-		 * so we must make sure they all match */
+		/* Status checked here are those returned by get_http_response()
+		 * so we must make sure they all match. */
 		if (status == HTTP_CONTINUE) {
 			free2(response);
 			status = get_http_response(sock, "GET", "", url, &new_url, &response, &recv_status);
@@ -241,25 +237,25 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 			return status;
 		} else if (status == OK) {
 			if (strcmp(get_http_header_value("Transfer-Encoding", response), "chunked") == 0) {
-				/* chunked transfer encoding */
+				/* Chunked transfer encoding */
 				remove_chunk_info(&response);
 			} else if ((content_length = atoi(get_http_header_value("Content-Length", response))) > 0) {
 				/* 'Content-Length' = length of entity body is mandatory
-				 * but if 'Transfer-Encoding: chunked' */
-				/* do nothing */
+				 * but if 'Transfer-Encoding: chunked'. */
+				/* Do nothing */
 			} else {
-#ifdef VERBOSE_OUTPUT		/* only if verbose because notification only, nothing done */
+#ifdef VERBOSE_OUTPUT		/* Only if verbose because notification only, nothing done. */
 				fprintf(STD_ERR, "No 'Transfer-Encoding' nor 'Content-Length' "
 					"header field in HTTP response\n");
 #endif
 			}
-			/* quickly 'check format' (xml and rss2.0/atom stuff),
-			 * shift to beginnig and cut off trailing part */
+			/* Quickly 'check format' (xml and rss2.0/atom stuff),
+			 * shift to beginnig and cut off trailing part. */
 			if ((j = format_quick_check(response, &i)) != OK) {
 				free2(response);
 				return j;
 			}
-			/* if ok, save to dump file */
+			/* If OK, save to dump file. */
 			if ((fp = g_fopen(file_name, "wb+")) != NULL) {
 				fprintf(fp, "%s", response + i);
 				fclose(fp);
@@ -311,7 +307,7 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 			current_feed();
 			return status;
 		} else if (status == HTTP_PROXY_AUTH_REQUIRED) {
-			/* proxy authentication */
+			/* Proxy authentication */
 			free2(response);
 			CLOSE_SOCK(sock);
 			if (get_use_proxy_auth()) {
@@ -424,15 +420,15 @@ int fetch_resource(const char *resrc_id, const char *file_name, char *url)
 	}
 }
 
-/* rq_str may contain header fields(s) separated and ended by "\r\n" */
+/* 'rq_str' may contain header fields(s) separated and ended by "\r\n" */
 const char *build_http_request(const char *method, const char *path,\
 		const char *host, const char* rq_str)
 {
 	static char	str[HTTP_REQUEST_MAXLEN + 1];
 
 	snprintf(str, HTTP_REQUEST_MAXLEN,
-		"%s %s HTTP/1.1\r\n"	/* start line with method and path */
-		"Host: %s\r\n"		/* mandatory host header field */
+		"%s %s HTTP/1.1\r\n"	/* Start line with method and path */
+		"Host: %s\r\n"		/* Mandatory host header field */
 		"User-Agent: "APP_NAME"-"APP_VERSION_NUMBER"\r\n"
 		"%s\r\n",		/* optional extra header field(s) */
 		method, path, host, rq_str);
@@ -440,8 +436,8 @@ const char *build_http_request(const char *method, const char *path,\
 }
 
 /*
- * rq_str may contain header field(s) separated and ended by "\r\n"
- * must 'free2' response afterwards
+ * 'rq_str' may contain header field(s) separated and ended by "\r\n".
+ * Must 'free2' response afterwards.
  */
 int get_http_response(sockt sock, const char *rq_method, const char *rq_str,
 	const char *rq_url, char **new_rq_url, char **response, int *recv_status)
@@ -455,7 +451,7 @@ int get_http_response(sockt sock, const char *rq_method, const char *rq_str,
 	*response = NULL;
 	str = (char *)build_http_request(
 		rq_method,
-		(get_use_proxy() ? rq_url : get_path_from_url(rq_url)),	/* path or full (absolute) url if using proxy */
+		(get_use_proxy() ? rq_url : get_path_from_url(rq_url)),	/* Path or full (absolute) url if using proxy */
 		/* is that correct when using proxy? */
 		get_host_from_url(rq_url),
 		rq_str);
@@ -467,21 +463,21 @@ int get_http_response(sockt sock, const char *rq_method, const char *rq_str,
 				return HTTP_SWITCH_PROTO;
 			else if (status_code == 200)
 				return OK;
-			else if (	/* 'multiple choices' */
+			else if (	/* 'Multiple choices' */
 					status_code == 300 ||\
-					/* 'moved permanently' */
+					/* 'Moved permanently' */
 					status_code == 301 ||\
-					/* 'found' */
+					/* 'Found' */
 					status_code == 302 ||\
-					/* 'see other' */
+					/* 'See other' */
 					status_code == 303 ||\
-					/* 'not modified' */
+					/* 'Not modified' */
 					status_code == 304 ||\
-					/* 'moved temporarily' */
+					/* 'Moved temporarily' */
 					status_code == 307) {
 				str_n_cpy(location, get_http_header_value("Location", *response),
 					FILE_NAME_MAXLEN);
-				return HTTP_MOVED;	/* must use the new url in 'Location' */
+				return HTTP_MOVED;	/* Must use the new url in 'Location' */
 			} else if (status_code == 305)
 				return HTTP_USE_PROXY;
 			else if (status_code == 400)
@@ -506,7 +502,7 @@ int get_http_response(sockt sock, const char *rq_method, const char *rq_str,
 		return SEND_ERROR;
 }
 
-/* return -1 if error */
+/* Return -1 if error */
 int get_http_status_code(const char *response)
 {
 	char	status_code[4];
@@ -527,7 +523,7 @@ int get_http_status_code(const char *response)
 	return atoi(status_code);
 }
 
-/* get header_value as string (empty one if header name not found) */
+/* Get header_value as string (empty one if header name not found) */
 const char *get_http_header_value(const char *header_name, const char *response)
 {
 	static char	header_value[1024];
@@ -562,7 +558,7 @@ const char *get_http_header_value(const char *header_name, const char *response)
 	return (const char *)header_value;
 }
 
-/* return 0 if none found */
+/* Return 0 if none found */
 int go_after_next_cr_lf(const char *response)
 {
 	int	i = 0;
@@ -575,7 +571,7 @@ int go_after_next_cr_lf(const char *response)
 		return 0;
 }
 
-/* return 0 if none found */
+/* Return 0 if none found */
 int go_after_next_empty_line(const char *response)
 {
 	int	i = 0;
@@ -588,8 +584,8 @@ int go_after_next_empty_line(const char *response)
 		return 0;
 }
 
-/* response must point to chunk size hexa str or preceeding space(s)
- * return -1 if invalid chunk size format (ie not an hexa str) */
+/* 'response' must point to chunk size hexa str or preceeding space(s).
+ * Return -1 if invalid chunk size format (ie not an hexa str). */
 int get_http_chunk_size(const char *response)
 {
 	char	size_str[32], *tailptr;
@@ -617,7 +613,7 @@ int get_http_chunk_size(const char *response)
 
 /*
  * 'http://www.sth1.org/sth2/sth2.xml' -> 'http'
- * (expect one scheme in url, return empty str if none)
+ * (expect one scheme in url, return empty str if none).
  */
 const char *get_scheme_from_url(const char* url)
 {
@@ -635,7 +631,7 @@ const char *get_scheme_from_url(const char* url)
 
 /*
  * 'http://www.sth1.org/sth2/sth2.xml' -> 'www.sth1.org'
- * (expect one scheme in url, return empty str if none)
+ * (expect one scheme in url, return empty str if none).
  */
 const char *get_host_from_url(const char* url)
 {
@@ -657,7 +653,7 @@ const char *get_host_from_url(const char* url)
 
 /*
  * 'http://www.sth1.org/sth2/sth2.xml' -> '/sth2/sth2.xml'
- * (expect one scheme in url, return empty str if none)
+ * (expect one scheme in url, return empty str if none).
  */
 const char *get_path_from_url(const char* url)
 {
