@@ -19,12 +19,6 @@
 #include "tickr.h"
 #include "tickr_list.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
-#if USE_GUI
-/* TODO: more testing of these funcs */
 FList *f_list_new(const char *url, const char *title, gboolean selected)
 {
 	FList	*node = malloc2(sizeof(FList));
@@ -37,9 +31,9 @@ FList *f_list_new(const char *url, const char *title, gboolean selected)
 	str_n_cpy(node->title, title, FLIST_TITLE_MAXLEN);
 
 	/*
-	 * if we want to use the following code (which save memory use),
+	 * If we want to use the following code (which save memory use),
 	 * we must implement funcs that reallocate memory when modifying
-	 * data and we must never modify it directly
+	 * data and we must never modify it directly.
 	 */
 	/*url_len = MIN(strlen(url), FLIST_URL_MAXLEN);
 	node->url = malloc2(url_len + 1);
@@ -59,7 +53,7 @@ FList *f_list_new(const char *url, const char *title, gboolean selected)
 }
 
 /*
- * free allocated memory
+ * Free allocated memory.
  */
 void f_list_free(FList *node)
 {
@@ -72,7 +66,7 @@ void f_list_free(FList *node)
 }
 
 /*
- * free allocated memory
+ * Free allocated memory.
  */
 void f_list_free_all(FList *some_node)
 {
@@ -103,7 +97,7 @@ FList *f_list_last(FList *node)
 }
 
 /*
- * return NULL if no previous node
+ * Return NULL if no previous node.
  */
 FList *f_list_prev(FList *node)
 {
@@ -116,7 +110,7 @@ FList *f_list_prev(FList *node)
 }
 
 /*
- * return NULL if no next node
+ * Return NULL if no next node.
  */
 FList *f_list_next(FList *node)
 {
@@ -129,7 +123,7 @@ FList *f_list_next(FList *node)
 }
 
 /*
- * return NULL if out of range
+ * Return NULL if out of range.
  */
 FList *f_list_nth(FList *some_node, int n)
 {
@@ -154,7 +148,7 @@ FList *f_list_nth(FList *some_node, int n)
 }
 
 /*
- * return index if found (starting at 0) / -1 otherwise
+ * Return index if found (starting at 0) / -1 otherwise.
  */
 int f_list_index(FList *some_node)
 {
@@ -187,8 +181,8 @@ int f_list_count(FList *some_node)
 }
 
 /*
- * create and add node at start of list
- * some_node may be any node in the list or NULL -> when creating list
+ * Create and add node at start of list.
+ * 'some_node' may be any node in the list or NULL -> when creating list.
  */
 FList *f_list_add_at_start(FList *some_node, const char *url, const char *title, gboolean selected)
 {
@@ -204,8 +198,8 @@ FList *f_list_add_at_start(FList *some_node, const char *url, const char *title,
 }
 
 /*
- * create and add node at end of list
- * some_node may be any node in the list or NULL -> when creating list
+ * Create and add node at end of list.
+ * 'some_node' may be any node in the list or NULL -> when creating list.
  */
 FList *f_list_add_at_end(FList *some_node, const char *url, const char *title, gboolean selected)
 {
@@ -221,7 +215,7 @@ FList *f_list_add_at_end(FList *some_node, const char *url, const char *title, g
 }
 
 /*
- * create and insert node before some_node
+ * Create and insert node before 'some_node'.
  */
 FList *f_list_insert_before(FList *some_node, const char *url, const char *title, gboolean selected)
 {
@@ -240,7 +234,7 @@ FList *f_list_insert_before(FList *some_node, const char *url, const char *title
 }
 
 /*
- * create and insert node after some_node
+ * Create and insert node after 'some_node'.
  */
 FList *f_list_insert_after(FList *some_node, const char *url, const char *title, gboolean selected)
 {
@@ -260,7 +254,7 @@ FList *f_list_insert_after(FList *some_node, const char *url, const char *title,
 }
 
 /*
- * remove then return first node or NULL if empty
+ * Remove then return first node or NULL if empty.
  */
 FList *f_list_remove(FList *node)
 {
@@ -301,8 +295,8 @@ void f_list_swap(FList *node1, FList *node2)
 }
 
 /*
- * sort by node->url then remove duplicated and empty entries
- * then return first node
+ * Sort by node->url, then remove duplicated and empty entries,
+ * then return first node.
  */
 FList *f_list_sort(FList *some_node)
 {
@@ -320,7 +314,7 @@ FList *f_list_sort(FList *some_node)
 			break;
 	}
 	list_len = i;
-	/* selection sort */
+	/* Selection sort */
 	for (i = 0; i < list_len; i++) {
 		min = i;
 		for (j = i + 1; j < list_len; j++)
@@ -330,20 +324,20 @@ FList *f_list_sort(FList *some_node)
 		node_i[i] = node_i[min];
 		node_i[min] = tmp;
 	}
-	/* remove duplicated entries */
+	/* Remove duplicated entries */
 	for (i = 0; i < list_len; i++)
 		for (j = i + 1; j < list_len; j++)
 			if (strcmp(node_i[i]->url, node_i[j]->url) == 0) {
-				if (node_i[j]->title[0] == '\0')	/* if no title in the second entry */
+				if (node_i[j]->title[0] == '\0')	/* If no title in the second entry */
 					node_i[j]->url[0] = '\0';	/* (ie the last added), we keep the */
-				else					/* first one */
+				else					/* first one. */
 					node_i[i]->url[0] = '\0';
 				if (node_i[i]->selected || node_i[j]->selected) {
 					node_i[i]->selected = TRUE;
 					node_i[j]->selected = TRUE;
 				}
 			}
-	/* remove empty entries */
+	/* Remove empty entries */
 	for (i = 0; i < list_len; i++)
 		if (node_i[i]->url[0] != '\0')
 			node2 = f_list_add_at_end(node2, node_i[i]->url, node_i[i]->title, node_i[i]->selected);
@@ -353,7 +347,7 @@ FList *f_list_sort(FList *some_node)
 }
 
 /*
- * search by node->url and return index if found (starting at 0) / -1 otherwise
+ * Search by node->url and return index if found (starting at 0) / -1 otherwise.
  */
 int f_list_search(FList *some_node, const char *str)
 {
@@ -372,16 +366,16 @@ int f_list_search(FList *some_node, const char *str)
 }
 
 /*
- * use provided file_name if not NULL / default file name (URL_LIST_FILE) otherwise
- * create new f_list
+ * Use provided file_name if not NULL / default file name (URL_LIST_FILE) otherwise.
+ * Create new f_list.
  *
- * entry format in url list file:
+ * Entry format in url list file:
  *	["*" (selected) or "-" (unselected) + url [+ ">" + title] + '\n']
  *
- * entry max length = FILE_NAME_MAXLEN
- * see also: (UN)SELECTED_URL_CHAR in tickr.h
+ * Entry max length = FILE_NAME_MAXLEN.
+ * See also: (UN)SELECTED_URL_CHAR and TITLE_TAG_CHAR in tickr.h.
  *
- * return OK (and first node of list) or LOAD_URL_LIST_ERROR
+ * Return OK (and first node of list) or LOAD_URL_LIST_ERROR.
  */
 int f_list_load_from_file(FList **new_node, const char *file_name)
 {
@@ -390,7 +384,7 @@ int f_list_load_from_file(FList **new_node, const char *file_name)
 	char		*tmp;
 	FList		*node;
 	size_t		tmp_size = FILE_NAME_MAXLEN + 1;
-	gboolean	selected;
+	gboolean	selected, title_found;
 	int		title_shift, i;
 
 	if (file_name == NULL) {
@@ -403,7 +397,9 @@ int f_list_load_from_file(FList **new_node, const char *file_name)
 #endif
 		listfname = listfname1;
 		if ((fp = g_fopen(listfname, "rb")) == NULL) {
-			if (question_win("No URL list has been saved yet. Use sample one ?") == YES)
+			if (question_win("No URL list has been saved yet. Import one (OPML format required) ?") == YES)
+				import_opml_file();
+			else if (question_win("No URL list has been saved yet. Use sample one ?") == YES)
 				listfname = listfname2;
 			else
 				return LOAD_URL_LIST_ERROR;
@@ -421,10 +417,12 @@ int f_list_load_from_file(FList **new_node, const char *file_name)
 			if (tmp[0] == SELECTED_URL_CHAR || tmp[0] == UNSELECTED_URL_CHAR) {
 				selected = (tmp[0] == SELECTED_URL_CHAR) ? TRUE : FALSE;
 				title_shift = -1;
+				title_found = FALSE;
 				for (i = 0; i < FILE_NAME_MAXLEN; i++) {
-					if (tmp[i] == TITLE_TAG_CHAR) {
+					if (!title_found && tmp[i] == TITLE_TAG_CHAR) {
 						title_shift = i + 1;
 						tmp[i] = '\0';
+						title_found = TRUE;
 					} else if (tmp[i] == '\n') {
 						tmp[i] = '\0';
 						break;
@@ -450,15 +448,15 @@ int f_list_load_from_file(FList **new_node, const char *file_name)
 }
 
 /*
- * use provided file_name if not NULL / default file name (URL_LIST_FILE) otherwise
+ * Use provided file_name if not NULL / default file name (URL_LIST_FILE) otherwise.
  *
- * entry format in url list file:
+ * Entry format in url list file:
  *	["*" (selected) or "-" (unselected) + url [+ ">" + title] + '\n']
  *
- * entry max length = FILE_NAME_MAXLEN
- * see also: (UN)SELECTED_URL_CHAR in tickr.h
+ * Entry max length = FILE_NAME_MAXLEN.
+ * See also: (UN)SELECTED_URL_CHAR and TITLE_TAG_CHAR in tickr.h.
  *
- * return OK (and first node of list) or SAVE_URL_LIST_ERROR
+ * Return OK (and first node of list) or SAVE_URL_LIST_ERROR.
  */
 int f_list_save_to_file(FList *node, const char *file_name)
 {
@@ -483,9 +481,8 @@ int f_list_save_to_file(FList *node, const char *file_name)
 		l_str_free(listfname);
 		return OK;
 	} else {
-		l_str_free(listfname);
 		warning(FALSE, 4, "Can't save URL list ", listfname, ": ", strerror(errno));
+		l_str_free(listfname);
 		return SAVE_URL_LIST_ERROR;
 	}
 }
-#endif
