@@ -19,27 +19,33 @@
 #include "tickr.h"
 
 #ifdef G_OS_WIN32
-FILE	*stdout_fp, *stderr_fp;
+FILE			*stdout_fp, *stderr_fp;
 #endif
-
 static TickerEnv	*env;
-static Resource		*resrc;
+static Resource	*resrc;
 static FList		*feed_list;
 static FList		*feed_selection;
 static Params		*prm;
 static int		instance_id = 0;
+static gboolean	no_ui = FALSE;
 static int		shift_counter = 0;
-#if USE_GUI
 static GtkWidget	*popup_menu;
 static GtkAccelGroup	*popup_menu_accel_group;
 static int		popup_menu_accel_group_attached;
 static int		position_x_in_drwa;
-#endif
 static GtkWidget	*main_hbox, *vbox_ticker, *vbox_clock;
 static int		speed_up_flag = FALSE;
 static int		speed_down_flag = FALSE;
 
 #define START_PAUSE_TICKER_WHILE_OPENING\
+	int	suspend_rq_bak = env->suspend_rq;\
+	env->suspend_rq = TRUE;
+
+#define END_PAUSE_TICKER_WHILE_OPENING\
+	env->suspend_rq = suspend_rq_bak;
+
+/* Sometimes, we need to temporarily re-enable popups, just to get error messages. */
+#define START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING\
 	int	suspend_rq_bak;\
 	char	disable_popups_bak;\
 	suspend_rq_bak = env->suspend_rq;\
@@ -47,11 +53,16 @@ static int		speed_down_flag = FALSE;
 	disable_popups_bak = get_params()->disable_popups;\
 	get_params()->disable_popups = 'n';
 
-#define END_PAUSE_TICKER_WHILE_OPENING	\
+#define END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING\
 	get_params()->disable_popups = disable_popups_bak;\
 	env->suspend_rq = suspend_rq_bak;
 
-/* prototypes for a few static funcs */
+/* Replace USE_GUI macro which has been there and ***unused*** for ages
+ * and breaks compile. */
+#define IF_UI_ALLOWED	if (!no_ui)
+
+/* Prototypes for a few static funcs */
+static void show_resource_info();
 static gint shift2left_callback();
 static void check_time_load_resource(check_time_mode);
 
@@ -95,20 +106,6 @@ int get_instance_id()
 	return instance_id;
 }
 
-#if USE_GUI	/* maybe this compile #if should be removed because
-		 * it has been there and ***unused*** for a long time
-		 * and it probably breaks compile anyways */
-void toggle_speed_up_flag()
-{
-	speed_up_flag = TRUE;
-}
-
-void toggle_speed_down_flag()
-{
-	speed_down_flag = TRUE;
-}
-#endif
-
 void check_main_win_always_on_top()
 {
 	if (prm->always_on_top == 'y')
@@ -117,92 +114,79 @@ void check_main_win_always_on_top()
 		gtk_window_set_keep_above(GTK_WINDOW(env->win), FALSE);
 }
 
-#if USE_GUI
 /*
  * funct_name2(***NO args***) only used to call funct_name(***args***)
  */
 static void get_new_url2()
 {
-	START_PAUSE_TICKER_WHILE_OPENING
-	get_new_url(resrc);
-	END_PAUSE_TICKER_WHILE_OPENING
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	IF_UI_ALLOWED
+		get_new_url(resrc);
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
 }
 
 static void open_new_txt_file2()
 {
-	START_PAUSE_TICKER_WHILE_OPENING
-	open_new_txt_file(resrc);
-	END_PAUSE_TICKER_WHILE_OPENING
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	IF_UI_ALLOWED
+		open_new_txt_file(resrc);
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
 }
 
 static void import_opml_file2()
 {
-	START_PAUSE_TICKER_WHILE_OPENING
-	import_opml_file();
-	END_PAUSE_TICKER_WHILE_OPENING
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	IF_UI_ALLOWED
+		import_opml_file();
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
 }
 
 static void export_opml_file2()
 {
-	START_PAUSE_TICKER_WHILE_OPENING
-	export_opml_file();
-	END_PAUSE_TICKER_WHILE_OPENING
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	IF_UI_ALLOWED
+		export_opml_file();
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
 }
 
-static void show_resource_info()
+static void show_resource_info2()
 {
-#define INFO_OPEN_TAG	""	/*"<b>"*/
-#define INFO_CLOSE_TAG	""	/*"</b>"*/
-	char	tmp[512];
-
-	START_PAUSE_TICKER_WHILE_OPENING
-	/* TODO: improve layout - use a table? */
-	if (resrc->type == RESRC_URL) {
-		snprintf(tmp, 511, "\n"
-			"Resource type:        "INFO_OPEN_TAG"%s Feed"INFO_CLOSE_TAG"\n\n"
-			"Feed title:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n\n"
-			"Feed URL:                "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
-			(resrc->format == RSS_2_0 ? "RSS 2.0" : (resrc->format == RSS_ATOM ? "Atom" : "RSS 1.0")),
-			resrc->feed_title, resrc->id);
-		info_win("Resource Properties", tmp, INFO, TRUE);
-	} else if (resrc->type == RESRC_FILE) {
-		snprintf(tmp, 511, "\n"
-			"Resource type:        "INFO_OPEN_TAG"File"INFO_CLOSE_TAG"\n\n"
-			"File name:               "INFO_OPEN_TAG"%s"INFO_CLOSE_TAG"\n",
-			resrc->id);
-		info_win("Resource Properties", tmp, INFO, TRUE);
-	} else
-		info_win("Resource Properties", "\nNo information available\n", INFO_ERROR, FALSE);
-	END_PAUSE_TICKER_WHILE_OPENING
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	show_resource_info();
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
 }
 
-static void modify_params2()
+void modify_params2()
 {
 	START_PAUSE_TICKER_WHILE_OPENING
-	if (modify_params(prm) == 1)	/* 1 means we want to reopen the dialog */
-		modify_params2(prm);
+	IF_UI_ALLOWED
+		if (modify_params(prm) == 1)	/* 1 means we want to immediately reopen the dialog */
+			modify_params2(prm);
 	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void connection_settings2()
 {
 	START_PAUSE_TICKER_WHILE_OPENING
-	if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK)
-		current_feed();
+	IF_UI_ALLOWED
+		if (connection_settings(AUTH_PAGE) == GTK_RESPONSE_OK)
+			current_feed();
 	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void import_params2()
 {
 	START_PAUSE_TICKER_WHILE_OPENING
-	import_params();
+	IF_UI_ALLOWED
+		import_params();
 	END_PAUSE_TICKER_WHILE_OPENING
 }
 
 static void export_params2()
 {
 	START_PAUSE_TICKER_WHILE_OPENING
-	export_params();
+	IF_UI_ALLOWED
+		export_params();
 	END_PAUSE_TICKER_WHILE_OPENING
 }
 
@@ -271,6 +255,126 @@ static void last_feed2()
 		info_win_wait("Single selection mode", INFO_WIN_WAIT_TIMEOUT);
 }
 
+void toggle_speed_up_flag()
+{
+	speed_up_flag = TRUE;
+}
+
+void toggle_speed_down_flag()
+{
+	speed_down_flag = TRUE;
+}
+
+static void help_win2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	help_win();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void online_help2()
+{
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	online_help();
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+}
+
+static void check_for_updates2()
+{
+	START_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+	check_for_updates();
+	END_PAUSE_TICKER_ENABLE_POPUPS_WHILE_OPENING
+}
+
+static void about_win2()
+{
+	START_PAUSE_TICKER_WHILE_OPENING
+	about_win();
+	END_PAUSE_TICKER_WHILE_OPENING
+}
+
+static void show_resource_info()
+{
+	GtkWidget	*dialog, *table, *label[7], *close_but;
+	char		tmp[256];
+	int		i;
+
+	if (resrc->type != RESRC_URL && resrc->type != RESRC_FILE) {
+		info_win("Resource Properties", "\nNo information available\n", INFO_ERROR, FALSE);
+		return;
+	}
+
+	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
+
+	dialog = gtk_dialog_new_with_buttons(
+			"Resource Properties", GTK_WINDOW(get_ticker_env()->win),
+			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+			NULL);
+
+	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+	close_but = close_but;	/* To get rid of one stupid compiler warning */
+
+	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
+	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+
+	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
+	g_signal_connect(G_OBJECT(dialog), "delete_event", G_CALLBACK(force_quit_dialog), NULL);
+
+	table = gtk_table_new(3, 3, FALSE);
+	gtk_table_set_row_spacings(GTK_TABLE(table), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(table), 15);
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
+
+	label[0] = gtk_label_new("        ");
+	if (resrc->type == RESRC_URL) {
+		label[1] = gtk_label_new("Resource type:");
+		snprintf(tmp, 256, "%s Feed", resrc->format == RSS_2_0 ? "RSS 2.0" : \
+			(resrc->format == RSS_ATOM ? "Atom" : "RSS 1.0"));
+		label[2] = gtk_label_new(tmp);
+
+		label[3] = gtk_label_new("Feed title:");
+		label[4] = gtk_label_new(resrc->feed_title);
+
+		label[5] = gtk_label_new("Feed URL:");
+		snprintf(tmp, 256, "<a href=\"%s\">%s</a>", resrc->id, resrc->id);
+		label[6] = gtk_label_new(tmp);
+		gtk_label_set_use_markup(GTK_LABEL(label[6]), TRUE);
+
+		for (i = 0; i < 7; i++)
+			gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
+	} else if (resrc->type == RESRC_FILE) {
+		label[1] = gtk_label_new("Resource type:  ");
+		label[2] = gtk_label_new("File");
+
+		label[3] = gtk_label_new("File name:  ");
+		label[4] = gtk_label_new(resrc->id);
+		gtk_label_set_selectable(GTK_LABEL(label[4]), TRUE);
+
+		for (i = 0; i < 5; i++)
+			gtk_misc_set_alignment(GTK_MISC(label[i]), 0, 0.5);
+	}
+
+	gtk_table_attach_defaults(GTK_TABLE(table), label[0], 1, 2, 0, 1);
+
+	gtk_table_attach_defaults(GTK_TABLE(table), label[1], 0, 1, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(table), label[2], 2, 3, 0, 1);
+
+	gtk_table_attach_defaults(GTK_TABLE(table), label[3], 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(table), label[4], 2, 3, 1, 2);
+
+	if (resrc->type == RESRC_URL) {
+		gtk_table_attach_defaults(GTK_TABLE(table), label[5], 0, 1, 2, 3);
+		gtk_table_attach_defaults(GTK_TABLE(table), label[6], 2, 3, 2, 3);
+	}
+
+	gtk_widget_show_all(dialog);
+	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CLOSE);
+
+	gtk_widget_destroy(dialog);
+	check_main_win_always_on_top();
+}
+
 #ifdef G_OS_WIN32
 static int easily_link_with_browser2()
 {
@@ -279,7 +383,7 @@ static int easily_link_with_browser2()
 	int		exit_status = NO;
 
 	if ((browser_cmd_p = (char *)get_default_browser_from_win32registry()) != NULL) {
-		/* find 1st str in browser_cmd */
+		/* Find 1st str in browser_cmd */
 		str_n_cpy(tmp, browser_cmd_p, 511);
 		for (i = 0, count = 0; i < strlen(tmp); i++) {
 			if (tmp[i] == '"') {
@@ -301,11 +405,11 @@ static int easily_link_with_browser2()
 			if (question_win("Save this parameter ?") == YES)
 				save_to_config_file(prm);
 		} else
-			info_win(APP_NAME, "\nCancelled.\n"
+			info_win("", "\nCancelled.\n"
 				"You may too set this parameter manually in the Preferences window.\n",
 				INFO, FALSE);
 	} else
-		info_win(APP_NAME" - Error", "\nCan't find Browser shell command."
+		info_win("", "\nCan't find Browser shell command."
 			"You will have to set this parameter manually in the Preferences window.\n",
 			INFO_ERROR, FALSE);
 	return exit_status;
@@ -340,7 +444,7 @@ static void open_link()
 #ifdef G_OS_WIN32
 	char		*tmp;
 #endif
-	char		*argv[32];	/* up to 32 - 3 (prog name, url, NULL) args */
+	char		*argv[32];	/* Up to 32 - 3 (prog name, url, NULL) args */
 	GPid		pid;
 	GError		*error = NULL;
 	int		i, j;
@@ -389,7 +493,7 @@ static void open_link()
 	if (!g_spawn_async(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &pid, &error)) {
 		warning(FALSE, 3, APP_NAME": Can't create process ", argv[0], " - ", error->message);
 #ifndef G_OS_WIN32
-		info_win(APP_NAME" - Warning", "Please check the 'Open in Browser' option in the Preferences window.",
+		info_win("", "Please check the 'Open in Browser' option in the Preferences window.",
 			INFO_WARNING, FALSE);
 #else
 		if (easily_link_with_browser2() == YES)
@@ -406,12 +510,14 @@ static void open_link2()
 	open_link();
 }
 
-static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event)
+static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event_but)
 {
 	widget = widget;
-	if (event->type == GDK_BUTTON_PRESS && event->button == 1) {	/* 1 = mouse left button */
-		/* get pointer x location on drawing_area */
-		position_x_in_drwa = event->x;
+	if (prm->disable_leftclick == 'y')
+		return FALSE;
+	if (event_but->type == GDK_BUTTON_PRESS && event_but->button == 1) {	/* 1 = mouse left button */
+		/* Get pointer x location on drawing_area */
+		position_x_in_drwa = event_but->x;
 		get_visible_link();
 		open_link();
 		return TRUE;
@@ -419,12 +525,12 @@ static gint left_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event)
 		return FALSE;
 }
 
-static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event)
+static gint right_click_on_drawing_area(GtkWidget *widget, GdkEventButton *event_but)
 {
 	widget = widget;
-	if (event->type == GDK_BUTTON_PRESS && event->button == 3) {	/* 3 = mouse right button */
-		/* popup main menu */
-		gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL, NULL, NULL, event->button, event->time);
+	if (event_but->type == GDK_BUTTON_PRESS && event_but->button == 3) {	/* 3 = mouse right button */
+		/* Popup main menu */
+		gtk_menu_popup(GTK_MENU(popup_menu), NULL, NULL, NULL, NULL, event_but->button, event_but->time);
 		return TRUE;
 	} else
 		return FALSE;
@@ -435,7 +541,7 @@ static const char *get_win_title_tooltip_text()
 	static char	tmp1[2][256 + 64], tmp2[2][64];
 	static int	i = -1;
 
-	/* to allow 2 simultaneous calls */
+	/* To allow 2 simultaneous calls */
 	i++;
 	i &= 1;
 
@@ -449,7 +555,7 @@ static const char *get_win_title_tooltip_text()
 	return (const char *)str_n_cat(tmp1[i], tmp2[i], 63);
 }
 
-/* pause ticker when mouse pointer is over (opened) popup menu */
+/* Pause ticker when mouse pointer is over (opened) popup menu. */
 static gint mouse_over_opened_popup_menu(GtkWidget *widget, GdkEvent *event)
 {
 	widget = widget;
@@ -462,7 +568,7 @@ static gint mouse_over_opened_popup_menu(GtkWidget *widget, GdkEvent *event)
 	return FALSE;
 }
 
-/* pause ticker on mouseover */
+/* Pause ticker on mouseover. */
 static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event)
 {
 	widget = widget;
@@ -482,16 +588,26 @@ static gint mouse_over_drawing_area(GtkWidget *widget, GdkEvent *event)
 
 static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *event)
 {
+	char mouse_wheel_scroll;
+
 	widget = widget;
 	if (event->type == GDK_SCROLL) {
-		if (prm->mouse_wheel_scroll == 's') {
+		mouse_wheel_scroll = prm->mouse_wheel_scroll;
+		if (event->scroll.state & GDK_CONTROL_MASK) {
+			/* if ctrl pressed, invert mouse_wheel_scroll values */
+			if (mouse_wheel_scroll == 's')
+				mouse_wheel_scroll = 'f';
+			else if (mouse_wheel_scroll == 'f')
+				mouse_wheel_scroll = 's';
+		}
+		if (mouse_wheel_scroll == 's') {
 			if (event->scroll.direction == GDK_SCROLL_UP)
 				toggle_speed_up_flag();
 			else if (event->scroll.direction == GDK_SCROLL_DOWN)
 				toggle_speed_down_flag();
 			env->suspend_rq = FALSE;
 			return TRUE;
-		} else if (prm->mouse_wheel_scroll == 'f') {
+		} else if (mouse_wheel_scroll == 'f') {
 			if (env->selection_mode == MULTIPLE) {
 				if (event->scroll.direction == GDK_SCROLL_UP)
 					quick_feed_picker(GDK_SCROLL_UP);
@@ -500,7 +616,7 @@ static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *even
 				env->suspend_rq = FALSE;
 			} else
 				warning(FALSE, 2, "Single selection mode\n",
-					"(You have set 'Mouse wheel scrolling apply to: Feed')");
+					"(You have set 'Mouse wheel scrolling applies to: Feed')");
 			return TRUE;
 		}
 	}
@@ -508,7 +624,7 @@ static gint mouse_wheel_scroll_on_drawing_area(GtkWidget *widget, GdkEvent *even
 }
 
 /*
- * popup menu stuff
+ * Popup menu stuff
  */
 static GtkItemFactoryEntry popup_menu_item[] = {
 	{"/_File",		NULL, NULL, 0, "<Branch>", NULL},
@@ -527,7 +643,7 @@ static GtkItemFactoryEntry popup_menu_item[] = {
 
 	{"/File/sep",		NULL, NULL, 0, "<Separator>", NULL},
 
-	{"/File/Resource _Properties", "<control>P", show_resource_info, 0, "<StockItem>",
+	{"/File/Resource _Properties", "<control>P", show_resource_info2, 0, "<StockItem>",
 				(gconstpointer)GTK_STOCK_PROPERTIES},
 
 	{"/File/sep",		NULL, NULL, 0, "<Separator>", NULL},
@@ -589,14 +705,16 @@ static GtkItemFactoryEntry popup_menu_item[] = {
 
 	{"/_Help",		NULL, NULL, 0, "<Branch>", NULL},
 
-	{"/Help/Quick Help",	"F1", help_win, 0, "<StockItem>",
+	{"/Help/Quick Help",	"F1", help_win2, 0, "<StockItem>",
 				(gconstpointer)GTK_STOCK_HELP},
 
-	{"/Help/Online Help",	"<control>H", online_help, 0, NULL, NULL},
+	{"/Help/Online Help",	"<control>H", online_help2, 0, NULL, NULL},
+
+	{"/Help/Check for Updates", "<control>", check_for_updates2, 0, NULL, NULL},
 
 	{"/Help/sep",		NULL, NULL, 0, "<Separator>", NULL},
 
-	{"/Help/_About",	"<control>A", about_win, 0, "<StockItem>",
+	{"/Help/_About",	"<control>A", about_win2, 0, "<StockItem>",
 				(gconstpointer)GTK_STOCK_ABOUT},
 };
 
@@ -612,7 +730,6 @@ static GtkWidget *get_popup_menu_menu(GtkWidget *win)
 	gtk_item_factory_create_items(item_factory, n_popup_menu_items, popup_menu_item, NULL);
 	return gtk_item_factory_get_widget(item_factory, "<main>");
 }
-#endif
 
 static gint update_win_dims()
 {
@@ -624,11 +741,11 @@ static gint update_win_dims()
 
 	gtk_window_unmaximize(GTK_WINDOW(env->win));
 
-	/* this is to prevent win from becoming 'unshowable' */
+	/* This is to prevent win from becoming 'unshowable' */
 	if (prm->icon_in_taskbar == 'n')
 		gtk_window_deiconify(GTK_WINDOW(env->win));
 	/*
-	 * not about win dims but this must be checked too
+	 * Not about win dims but this must be checked too
 	 * (is there a better place?)
 	 */
 	check_main_win_always_on_top();
@@ -653,7 +770,7 @@ gboolean params_have_been_changed(Params *new_prm, int n_required_runs)
 }
 
 /*
- * create new or next cairo image surface & compute stuff to redraw window
+ * Create new or next cairo image surface & compute stuff to redraw window.
  */
 static int compute_surface_and_win()
 {
@@ -666,18 +783,18 @@ static int compute_surface_and_win()
 	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
 	gtk_window_unstick(GTK_WINDOW(env->win));
 	/*
-	 * compute font size from requested height if > 0
+	 * Compute font size from requested height if > 0
 	 */
 	split_font(prm->font_n_s, fname, fsize);
 	if (prm->win_h > 0)
 		snprintf(fsize, FONT_SIZE_MAXLEN + 1, "%3d",
 			get_fsize_from_layout_height((gint)prm->win_h, fname));
-	/* in all cases, font size can't be > FONT_MAXSIZE */
+	/* In all cases, font size can't be > FONT_MAXSIZE */
 	if (atoi(fsize) > FONT_MAXSIZE)
 		snprintf(fsize, FONT_SIZE_MAXLEN + 1, "%3d", FONT_MAXSIZE);
 	compact_font(prm->font_n_s, fname, fsize);
 	/*
-	 * compute clock font size
+	 * Compute clock font size
 	 * clock height = ticker height unless clock font size is set
 	 * in which case clock height is always <= ticker height
 	 */
@@ -695,7 +812,7 @@ static int compute_surface_and_win()
 	}
 	compact_font(prm->clock_font_n_s, cfname, cfsize);
 	/*
-	 * compute ticker width
+	 * Compute ticker width
 	 */
 	if (prm->win_w >= DRWA_WIDTH_MIN && prm->win_w <= env->screen_w)
 		env->drwa_width = prm->win_w;
@@ -705,7 +822,7 @@ static int compute_surface_and_win()
 		env->drwa_width = env->screen_w;
 	env->drwa_width -= (env->drwa_clock_width = get_clock_width(prm));
 	/*
-	 * reset link_and_offset stuff
+	 * Reset link_and_offset stuff
 	 */
 	if(resrc->id[0] == '\0' && resrc->fp != NULL) {
 		fclose(resrc->fp);
@@ -716,7 +833,7 @@ static int compute_surface_and_win()
 		}
 	}
 	/*
-	 * create cairo image surface of rendered text (one long single line)
+	 * Create cairo image surface of rendered text (one long single line)
 	 */
 	env->c_surf = render_stream_to_surface(resrc->fp, resrc->link_and_offset, prm, &render_exit_status);
 	if (render_exit_status != OK && render_exit_status != RENDER_NO_RESOURCE) {
@@ -750,68 +867,61 @@ static int compute_surface_and_win()
 	env->surf_height = cairo_image_surface_get_height(env->c_surf);
 	env->drwa_height = (MIN(env->surf_height, env->screen_h));
 	/*
-	 * window layout stuff
+	 * Window layout stuff
 	 */
-	/* win title */
+	/* Win title */
 	gtk_window_set_title(GTK_WINDOW(env->win), get_win_title_tooltip_text());
-	/*
-	 * when window-always-on-top is disabled, the following code needs to be run
-	 * only twice at program startup (ie once after gtk_widget_show_all() has been
-	 * called), then whenever params are changed, but not when a new feed is loaded
-	 * (this is to fix an issue with Unity on Ubuntu)
-	 */
-	if (prm->always_on_top == 'n' && !params_have_been_changed(prm, 2))
-		return render_exit_status;
-	/* move win */
+	/* Move win */
 	gtk_window_move(GTK_WINDOW(env->win), prm->win_x, prm->win_y);
-	/* win decoration */
+	/* Win decoration */
 	if (prm->windec == 'y') {
 		gtk_window_set_decorated(GTK_WINDOW(env->win), TRUE);
-#if USE_GUI
 		if (!popup_menu_accel_group_attached) {
 			gtk_window_add_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
 			popup_menu_accel_group_attached = TRUE;
 		}
-#endif
 	} else {
 		gtk_window_set_decorated(GTK_WINDOW(env->win), FALSE);
-#if USE_GUI
 		if (popup_menu_accel_group_attached) {
 			gtk_window_remove_accel_group(GTK_WINDOW(env->win), popup_menu_accel_group);
 			popup_menu_accel_group_attached = FALSE;
 		}
-#endif
 	}
-	/* clock */
+	/* Clock */
 	if (prm->clock == 'l')
 		gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 0);
 	else if (prm->clock == 'r')
 		gtk_box_reorder_child(GTK_BOX(main_hbox), vbox_clock, 1);
-	/* whole window transparency */
+	/* Whole window transparency */
 	gtk_window_set_opacity(GTK_WINDOW(env->win), prm->win_transparency);
-	/* window icon in taskbar? */
+	/* Window icon in taskbar? */
 	if (prm->icon_in_taskbar == 'y')
 		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), FALSE);
 	else if (prm->icon_in_taskbar == 'n')
 		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(env->win), TRUE);
-	/* window on all desktops? */
-	if (prm->win_sticky == 'y') {
+	/* Window on all desktops? */
+	if (prm->win_sticky == 'y')
 		gtk_window_stick(GTK_WINDOW(env->win));
-		gtk_window_present(GTK_WINDOW(env->win));	/* seems necessary but not sure why */
-	} else if (prm->win_sticky == 'n')
+	else if (prm->win_sticky == 'n')
 		gtk_window_unstick(GTK_WINDOW(env->win));
+	/* gtk_window_present() needs to be run
+	 * - twice at program startup (ie once after gtk_widget_show_all() has been called)
+	 * - whenever params have been changed
+	 * - not when a new feed is loaded. */
+	if (params_have_been_changed(prm, 2))
+		gtk_window_present(GTK_WINDOW(env->win));
 	check_main_win_always_on_top();
 	return render_exit_status;
 }
 
 /*
- * timeout handler to render one part of cairo image surface onto drawing
+ * Timeout handler to render one part of cairo image surface onto drawing
  * area - image is shifted to left by <shift_size> pixels
  *
- * handler 'listens' to flags: suspend_rq, reload_rq, compute_rq and
+ * Handler 'listens' to flags: suspend_rq, reload_rq, compute_rq and
  * stream_fully_read
  *
- * notes:
+ * Notes:
  * - reload_rq may be a misleading name as, in multiple selection mode,
  * we will load next stream, not reload the same one
  * - stream_fully_read is only relevant in multiple selection mode because
@@ -825,23 +935,23 @@ static gint shift2left_callback()
 	int		i;
 
 	if (env->suspend_rq)
-		return TRUE;	/* does nothing - just return */
+		return TRUE;	/* Does nothing - just return */
 	else if ((shift_counter * prm->shift_size < env->surf_width - env->drwa_width - 8) &&\
 			/*!(env->selection_mode == MULTIPLE && env->stream_fully_read) &&\*/
 			!env->reload_rq && !env->compute_rq) {
 		env->suspend_rq = TRUE;
 		/*
-		 * draw onto ticker area
+		 * Draw onto ticker area
 		 * (we now use cairo instead of deprecated gdk_draw_ stuff)
 		 */
-		/* double buffering disabled for drawing area so we need this */
+		/* Double buffering disabled for drawing area so we need this */
 		gdk_window_get_geometry(env->drw_a->window, &(r.x), &(r.y), NULL, NULL, NULL);
-		if (prm->clock == 'l')			/* we must do that but noy quite sure why */
+		if (prm->clock == 'l')			/* We must do that but not quite sure why */
 			r.x -= env->drwa_clock_width;
 		r.width = env->drwa_width;
 		r.height = env->drwa_height;
 		gdk_window_begin_paint_rect(env->drw_a->window, &r);
-		/* cairo stuff */
+		/* Cairo stuff */
 		cr = gdk_cairo_create(GDK_DRAWABLE(env->drw_a->window));
 		/* dest_x - src_x, dest_y - src_y */
 		cairo_set_source_surface(cr, env->c_surf, - (shift_counter++ * prm->shift_size), 0);
@@ -850,11 +960,11 @@ static gint shift2left_callback()
 		cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 		cairo_fill(cr);
 		cairo_destroy(cr);
-		/* we're done */
+		/* We're done */
 		gdk_window_end_paint(env->drw_a->window);
 		env->suspend_rq = FALSE;
 		/*
-		 * speeding up/down on the fly
+		 * Speeding up/down on the fly
 		 */
 		if (speed_up_flag == TRUE || speed_down_flag == TRUE) {
 			if (speed_up_flag == TRUE) {
@@ -876,8 +986,8 @@ static gint shift2left_callback()
 			return TRUE;
 	} else {
 		/*
-		 * when cairo_image surface scrolling completed or if request to
-		 * reload or recompute everything, will create new surface or next one
+		 * When cairo_image surface scrolling completed or if request to
+		 * reload or recompute everything, will create new surface or next one.
 		 */
 		env->suspend_rq = TRUE;
 		if (env->c_surf != NULL) {
@@ -925,7 +1035,7 @@ static gint shift2left_callback()
 			check_time_load_resource(TIME_RESET);
 		}
 		compute_surface_and_win();
-		shift_counter = prm->shift_size;	/* to avoid displaying twice the same thing */
+		shift_counter = prm->shift_size;	/* To avoid displaying twice the same thing */
 		g_timeout_add_full(G_PRIORITY_DEFAULT, prm->delay, shift2left_callback, NULL, NULL);
 		env->reload_rq = FALSE;
 		env->compute_rq = FALSE;
@@ -940,7 +1050,7 @@ static gint display_time2()
 	return TRUE;
 }
 
-static gint get_win_position()	/* only if win is 'draggable' */
+static gint get_win_position()	/* Only if win is 'draggable' */
 {
 	if (prm->windec == 'y')
 		gtk_window_get_position(GTK_WINDOW(env->win), &prm->win_x, &prm->win_y);
@@ -948,7 +1058,7 @@ static gint get_win_position()	/* only if win is 'draggable' */
 }
 
 /*
- * reload stuff every <resrc->rss_ttl * 60> seconds
+ * Reload stuff every <resrc->rss_ttl * 60> seconds
  */
 static void check_time_load_resource(check_time_mode mode)
 {
@@ -1007,9 +1117,9 @@ static void print_license()
 	fprintf(STD_OUT, "%s\n", get_license_str2());
 }
 
-/* reload resource as soon as scrolling has started to update all display params
+/* Reload resource as soon as scrolling has started to update all display params.
  * TODO: reset open stream to begining and recompute instead of reloading (which
- * is useless) -> must first make sure this doesn't break anything
+ * is useless) -> must first make sure this doesn't break anything.
  */
 gint update_everything()
 {
@@ -1024,7 +1134,7 @@ gint update_everything()
 }
 
 #ifdef G_OS_WIN32
-/* this is meant to be used with the new GTK/GLib-win32 runtime */
+/* This is meant to be used with the new GTK/GLib-win32 runtime. */
 static int init_win32_mmtimer()
 {
 	TIMECAPS	tc;
@@ -1051,7 +1161,7 @@ static void create_win32_logfiles()
 	fprintf(STD_ERR, "%s", ctime(&time2));
 }
 
-/* swap win32 log files every hour to prevent generating huge ones */
+/* Swap win32 log files every hour to prevent generating huge ones. */
 static gint swap_win32_logfiles()
 {
 	static unsigned long	elapsed_time_in_sec = 0;
@@ -1121,10 +1231,10 @@ int main(int argc, char *argv[])
 	env->active_link[0] = '\0';
 	env->suspend_rq = env->compute_rq = env->reload_rq = env->stream_fully_read = FALSE;
 	/* env->selection_mode: default = MULTIPLE, set to SINGLE internally if
-	 * selection is unavalaible/empty or after picking a single feed */
+	 * selection is unavalaible/empty or after picking a single feed. */
 	env->selection_mode = MULTIPLE;
 	/*
-	 * toplevel window
+	 * Toplevel window
 	 */
 	env->win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(env->win), APP_NAME"-"APP_VERSION_NUMBER);
@@ -1148,14 +1258,14 @@ int main(int argc, char *argv[])
 			exit(WIN32V_ERROR);
 #endif
 	/*
-	 * create dir in user home dir if it doesn't exist
+	 * Create dir in user home dir if it doesn't exist.
 	 */
 	g_mkdir(get_datadir_full_path(), S_IRWXU);
 #ifdef G_OS_WIN32
 	create_win32_logfiles();
 #endif
 	/*
-	 * get help, show license, set instance id or check available system fonts
+	 * Get help, show license, set instance id, run with no-ui, or check available system fonts.
 	 */
 	if (argc >= 2 && (strcmp(argv[1], "-help") == 0 || strcmp(argv[1], "--help") == 0 ||\
 			strcmp(argv[1], "-h") == 0 || strcmp(argv[1], "-?") == 0)) {
@@ -1174,22 +1284,24 @@ int main(int argc, char *argv[])
 			fprintf(STD_ERR, "Instance ID invalid value: %d\n", instance_id);
 			instance_id = 0;
 		}
-	} else if (argc >= 2 && (strcmp(argv[1], "-dumpfontlist") == 0 || strcmp(argv[1], "--dumpfontlist") == 0)) {
+	} else if (argc >= 2 && strncmp(argv[1], "-no-ui", strlen("-no-ui")) == 0)
+		no_ui = TRUE;
+	else if (argc >= 2 && (strcmp(argv[1], "-dumpfontlist") == 0 || strcmp(argv[1], "--dumpfontlist") == 0)) {
 		dump_font_list();
 		return 0;
 	}
 	set_tickr_icon_to_dialog(GTK_WINDOW(env->win));
 	/*
-	 * create rss icon
+	 * Create rss icon
 	 */
-	 pixb = gdk_pixbuf_new_from_file(get_imagefile_full_name_from_name(RSS_ICON), &error);
+	pixb = gdk_pixbuf_new_from_file(get_imagefile_full_name_from_name(RSS_ICON), &error);
 	icon_factory = gtk_icon_factory_new();
 	gtk_icon_factory_add(icon_factory, RSS_ICON, gtk_icon_set_new_from_pixbuf(pixb));
 	gtk_icon_factory_add_default(icon_factory);
 	if (pixb != NULL)
 		g_object_unref(pixb);
 	/*
-	 * get some system graphical params
+	 * Get some system graphical params
 	 */
 	env->screen = gtk_widget_get_screen(env->win);
 #ifndef G_OS_WIN32
@@ -1210,6 +1322,10 @@ int main(int argc, char *argv[])
 #ifdef VERBOSE_OUTPUT
 	fprintf(STD_OUT, "GDK visual: screen width = %d, screen height = %d, depth = %d\n",
 		env->screen_w, env->screen_h, env->depth);
+	if (no_ui)
+		warning(FALSE, 2, APP_NAME" will run with the 'no-ui' option.\n",
+			"Opening of UI elements which can modify settings and/or \n"
+			"URL list/selection is disabled.");
 #endif
 	resrc->type = RESRC_UNSPECIFIED;
 	resrc->format = RSS_FORMAT_UNDETERMINED;
@@ -1223,15 +1339,18 @@ int main(int argc, char *argv[])
 	init_authentication();
 	init_proxy();
 	/*
-	 * options and resource stuff
+	 * Options and resource stuff
 	 */
 	set_default_options(prm);	/* init all params */
-	get_config_file_options(prm);
+	if (g_file_test(get_datafile_full_name_from_name(CONFIG_FILE), G_FILE_TEST_EXISTS))
+		get_config_file_options(prm);
+	else
+		quick_setup(prm);
 
 	n_options = 0;
 	n_resources = 0;
 	if (argc > 1) {
-		/* parse args: first -options... then resource - the rest is ignored */
+		/* Parse args: first -options... then resource - the rest is ignored. */
 		for (i = 1; i < argc; i++)
 			if (argv[i][0] == '-')
 				n_options ++;
@@ -1259,7 +1378,7 @@ int main(int argc, char *argv[])
 	}
 	compute_auth_and_proxy_str();
 	/*
-	 * feed list stuff
+	 * Feed list stuff
 	 */
 	if ((i = f_list_load_from_file(&feed_list, NULL)) == OK) {
 		feed_list = f_list_sort(feed_list);
@@ -1297,25 +1416,23 @@ int main(int argc, char *argv[])
 	resrc->rss_ttl = prm->rss_refresh;
 	first_feed();
 	/*
-	 * set window layout
+	 * Set window layout
 	 */
 	main_hbox = gtk_hbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(env->win), main_hbox);
-#if USE_GUI
 	popup_menu = get_popup_menu_menu(NULL);
 	popup_menu_accel_group_attached = FALSE;
-#endif
 	/*
-	 * create 2 drawing areas
+	 * Create 2 drawing areas
 	 */
 	env->drw_a = gtk_drawing_area_new();
-	/* we disable double buffering for drawing area and will use
-	 * gdk_window_begin_paint_rect() and gdk_window_end_paint()
+	/* We disable double buffering for drawing area and will use
+	 * gdk_window_begin_paint_rect() and gdk_window_end_paint().
 	 */
 	gtk_widget_set_double_buffered(env->drw_a, FALSE);
 	env->drwa_clock = gtk_drawing_area_new();
 	gtk_widget_add_events(env->drw_a, GDK_ALL_EVENTS_MASK);	/* change mask? */
-#if USE_GUI
+
 	g_signal_connect(G_OBJECT(env->drw_a), "button-press-event", G_CALLBACK(left_click_on_drawing_area), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "button-press-event", G_CALLBACK(right_click_on_drawing_area), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "enter-notify-event", G_CALLBACK(mouse_over_drawing_area), NULL);
@@ -1323,7 +1440,7 @@ int main(int argc, char *argv[])
 	g_signal_connect(G_OBJECT(popup_menu), "expose-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
 	g_signal_connect(G_OBJECT(popup_menu), "leave-notify-event", G_CALLBACK(mouse_over_opened_popup_menu), NULL);
 	g_signal_connect(G_OBJECT(env->drw_a), "scroll-event", G_CALLBACK(mouse_wheel_scroll_on_drawing_area), NULL);
-#endif
+
 	vbox_ticker = gtk_vbox_new(FALSE, 0);	/* vbox_ticker is only used to have a v-centered ticker */
 	gtk_box_pack_start(GTK_BOX(vbox_ticker), GTK_WIDGET(env->drw_a), TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(main_hbox), vbox_ticker, FALSE, FALSE, 0);
@@ -1331,25 +1448,25 @@ int main(int argc, char *argv[])
 	gtk_box_pack_start(GTK_BOX(vbox_clock), GTK_WIDGET(env->drwa_clock), TRUE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(main_hbox), vbox_clock, FALSE, FALSE, 0);
 	/*
-	 * create cairo image surface from text file or rss feed & compute stuff to draw window
+	 * Create cairo image surface from text file or rss feed & compute stuff to draw window.
 	 */
 	compute_surface_and_win();
 
-	/* === timeout callbacks === */
+	/* === Timeout callbacks === */
 	/*
-	 * refresh the image every <delay> milliseconds
+	 * Refresh the image every <delay> milliseconds
 	 */
 	g_timeout_add_full(G_PRIORITY_DEFAULT, prm->delay, shift2left_callback, NULL, NULL);
 	/*
-	 * display clock every 0.5 seconds
+	 * Display clock every 0.5 seconds
 	 */
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 500, display_time2, NULL, NULL);
 	/*
-	 * get current win position (if 'dragged') every 0.5 seconds
+	 * Get current win position (if 'dragged') every 0.5 seconds
 	 */
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 500, get_win_position, NULL, NULL);
 	/*
-	 * check every sec until elapsed time in mn > <resrc->rss_ttl> mn then reload rss feed (or text file)
+	 * Check every sec until elapsed time in mn > <resrc->rss_ttl> mn then reload rss feed (or text file)
 	 */
 	check_time_load_resource(TIME_RESET);
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 1000, check_time_load_resource2, NULL, NULL);
@@ -1358,7 +1475,7 @@ int main(int argc, char *argv[])
 
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 100, update_everything, NULL, NULL);
 	/*
-	 * check every sec until elapsed time >= 1 hour then swap win32 log files to prevent generating huge ones
+	 * Check every sec until elapsed time >= 1 hour then swap win32 log files to prevent generating huge ones
 	 */
 #ifdef G_OS_WIN32
 	g_timeout_add_full(G_PRIORITY_DEFAULT, 1000, swap_win32_logfiles, NULL, NULL);
@@ -1372,7 +1489,7 @@ int main(int argc, char *argv[])
 	update_win_dims();
 	gtk_main();
 	/*
-	 * cleanup stuff
+	 * Cleanup stuff
 	 */
 	if (resrc->fp != NULL)
 		fclose(resrc->fp);
