@@ -18,25 +18,6 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
-#if USE_GUI
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
-{
-	if (event->keyval == GDK_Escape) {
-		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
-		return TRUE;
-	} else
-		return FALSE;
-}
-
-static void force_quit_dialog(GtkWidget *dialog2)
-{
-	gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
-}
-
 void import_params()
 {
 	GtkWidget	*dialog;
@@ -49,7 +30,9 @@ void import_params()
 
 	dialog = gtk_file_chooser_dialog_new("Import Preferences", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
+			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL */
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -73,6 +56,9 @@ void import_params()
 						while ((c = fgetc(fp1)) != (int)EOF)
 							fputc((int)c, fp2);
 						fclose(fp2);
+						/* ????
+						modify_params2();*/
+
 						current_feed();
 						get_ticker_env()->reload_rq = TRUE;
 					} else
@@ -99,15 +85,21 @@ void export_params()
 	int		c;
 
 	if ((fp1 = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "rb")) == NULL) {
-		warning(FALSE, 4, "Can't open file ", file_name, ": ", strerror(errno));
-		return;
+		save_to_config_file(get_params());
+		if ((fp1 = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "rb")) == NULL) {
+			warning(FALSE, 4, "Can't open file ", get_datafile_full_name_from_name(CONFIG_FILE)
+				, ": ", strerror(errno));
+			return;
+		}
 	}
 
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 	dialog = gtk_file_chooser_dialog_new("Export Preferences", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_SAVE,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
+			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL */
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -140,18 +132,18 @@ void export_params()
 	if (exit_status == OK) {
 		snprintf(tmp, TMPSTR_SIZE + 1,
 			"\nPreferences have been exported to file: %s\n", file_name);
-		info_win(APP_NAME, tmp, INFO, FALSE);
+		info_win("", tmp, INFO, FALSE);
 	}
 	if (file_name != NULL)
 		g_free(file_name);
 	check_main_win_always_on_top();
 }
 
-# ifndef G_OS_WIN32
+#ifndef G_OS_WIN32
 void online_help()
 {
 	char		tmp1[FILE_NAME_MAXLEN + 1];
-	char		*help_url = APP_SUPPORT_WEBSITE;
+	char		*help_url = SUPPORT_URL;
 	char		*argv[3];
 	GPid		pid;
 	GError		*error = NULL;
@@ -169,23 +161,23 @@ void online_help()
 	argv[2] = NULL;
 	if (!g_spawn_async(NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, &pid, &error)) {
 		warning(FALSE, 4, APP_NAME": Can't create process ", argv[0], " - ", error->message);
-		info_win("Warning", "Please check the 'Open in Browser' option in the Preferences window.",
+		info_win("", "Please check the 'Open in Browser' option in the Preferences window.",
 			INFO_WARNING, FALSE);
 	} else
 		g_spawn_close_pid(pid);
 }
-# else
+#else
 void online_help()
 {
 	char		*browser_cmd_p, browser_cmd[512], tmp[1024];
 	unsigned int	i, count, start = 0, end = 0;
-	char		link[] = APP_SUPPORT_WEBSITE;
+	char		link[] = SUPPORT_URL;
 	char		*argv[3];
 	GPid		pid;
 	GError		*error = NULL;
 
 	if ((browser_cmd_p = (char *)get_default_browser_from_win32registry()) != NULL) {
-		/* find 1st str in browser_cmd */
+		/* Find 1st str in browser_cmd */
 		str_n_cpy(tmp, browser_cmd_p, 511);
 		for (i = 0, count = 0; i < strlen(tmp); i++) {
 			if (tmp[i] == '"') {
@@ -197,7 +189,7 @@ void online_help()
 			}
 		}
 		str_n_cpy(browser_cmd, tmp + start, MIN((end - start + 1), 511));
-		/* launch browser */
+		/* Launch browser */
 		fprintf(STD_OUT, "Spawning: %s %s\n", browser_cmd, link);
 		argv[0] = browser_cmd;
 		argv[1] = link;
@@ -210,24 +202,23 @@ void online_help()
 			g_spawn_close_pid(pid);
 	}
 }
-# endif
 #endif
 
 /*
- * this func's prototype is in libetm / error.h
- * this func is not defined in libetm but in app and it handles errors
- * from libetm and app
+ * This func's prototype is in libetm / error.h.
+ * This func is not defined in libetm but in app and it handles errors
+ * from libetm and app.
  *
- * max number of strings = N_STR_MAX, max string length = STR_MAXLEN
- * outstanding stuff (strings and chars) will be ignored
+ * Max number of strings = N_STR_MAX, max string length = STR_MAXLEN.
+ * Outstanding stuff (strings and chars) will be ignored.
  */
 int big_error(int big_error_code, int n_str, ...)
 {
-#define N_STR_MAX		8
-#define STR_MAXLEN		128
+#define N_STR_MAX	8
+#define STR_MAXLEN	128
 
 	char		error_str[32 + 32 + (N_STR_MAX * STR_MAXLEN) + 32 + 1];
-	va_list		str;
+	va_list	str;
 	int		i;
 
 	get_ticker_env()->suspend_rq = TRUE;
@@ -247,9 +238,9 @@ int big_error(int big_error_code, int n_str, ...)
 		fprintf(STD_ERR, "%s\n", error_str);
 		fflush(NULL);
 	}
-#if USE_GUI
-	info_win(APP_NAME" - Error", error_str, INFO_ERROR, FALSE);
-#endif
+	/* We want this win to always popup */
+	get_params()->disable_popups = 'n';
+	info_win(APP_NAME" - Critical error", error_str, INFO_ERROR, FALSE);
 	if (get_resource()->fp != NULL)
 		fclose(get_resource()->fp);
 	free2(get_ticker_env());
@@ -258,14 +249,15 @@ int big_error(int big_error_code, int n_str, ...)
 	exit(big_error_code);
 }
 
-/* wait for INFO_WIN_WAIT_TIMEOUT ms if true */
+/* Will popup and wait for INFO_WIN_WAIT_TIMEOUT ms if wait == TRUE, then close
+ * otherwise, will block until an appropriate keyboard/mouse action happens. */
 void warning(gboolean wait, int n_str, ...)
 {
-#define N_STR_MAX		8
-#define STR_MAXLEN		128
+#define N_STR_MAX	8
+#define STR_MAXLEN	128
 
 	char		warning_str[N_STR_MAX * STR_MAXLEN + 1];
-	va_list		str;
+	va_list	str;
 	int		i;
 
 	warning_str[0] = '\0';
@@ -277,12 +269,10 @@ void warning(gboolean wait, int n_str, ...)
 
 	fprintf(STD_ERR, "%s\n", warning_str);
 	fflush(STD_ERR);
-#if USE_GUI
 	if (!wait)
-		info_win(APP_NAME" - Warning", warning_str, INFO_WARNING, FALSE);
+		info_win("", warning_str, INFO_WARNING, FALSE);
 	else
 		info_win_wait(warning_str, INFO_WIN_WAIT_TIMEOUT);
-#endif
 }
 
 void dump_font_list()
@@ -317,12 +307,8 @@ void dump_font_list()
 		}
 	}
 	font[k] = NULL;
-/*
- * not sure if we must g_free() sth?
- */
-	/*
-	 * sort array (selection sort)
-	 */
+	/* Not sure if we must g_free() sth ? */
+	/* Sort array (selection sort) */
 	for (i = 0; i < k; i++) {
 		min = i;
 		for (j = i  + 1; j < k; j++) {
