@@ -18,31 +18,12 @@
 
 #include "tickr.h"
 
-#if USE_GUI
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
 static char	*opml_str_global;
 static char	tmp_url[FILE_NAME_MAXLEN + 1], tmp_str[256];
 
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
-{
-	if (event->keyval == GDK_Escape) {
-		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
-		return TRUE;
-	} else
-		return FALSE;
-}
-
-static void force_quit_dialog(GtkWidget *dialog2)
-{
-	gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CANCEL);
-}
-
 /*
- * importing
+ * Importing
  */
-
 static int *get_feed_counter()
 {
 	static int	feed_counter;
@@ -105,14 +86,10 @@ void import_opml_file()
 		l_str_free(opml_str_global);
 		win_with_progress_bar(WIN_WITH_PROGRESS_BAR_CLOSE, NULL);
 		if (status == OK) {
-			/*snprintf(tmp_str, 256, "\nFeed list (%d URLs) has been imported\n",
+			snprintf(tmp_str, 256, "\nFeed list (%d URLs) has been imported\n",
 				*get_feed_counter());
-			info_win(APP_NAME, tmp_str, INFO, FALSE);*/
-			/* ok like that ? */
-			snprintf(tmp_str, 256, "\nFeed list (%d URLs) has been imported. "
-				"Open the Feed Picker window ?\n", *get_feed_counter());
-			if (question_win(tmp_str) == YES)
-				get_new_url(get_resource());
+			info_win("", tmp_str, INFO, FALSE);
+			get_new_url(get_resource());
 		}
 	}
 }
@@ -128,7 +105,9 @@ char *pick_opml_file()
 
 	dialog = gtk_file_chooser_dialog_new("Import Feed List (OPML)", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_OPEN,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
+			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL. */
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -213,20 +192,19 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 
 	for (cur_node = some_node; cur_node != NULL; cur_node = cur_node->next) {
 		if (xmlStrcmp(cur_node->name, (const xmlChar *)selected_element) == 0) {
-			/* need to get attribute name and value
-			 * then use only those whose value = "rss" for name = 'type'
-			 * then get value for name = 'xmlUrl' -> rss feed url
+			/* Need to get attribute name and value,
+			 * then use only those whose value = "rss" for name = 'type',
+			 * then get value for name = 'xmlUrl' -> rss feed url.
 			 */
 			if ((str1 = xmlGetProp(cur_node, (xmlChar *)selected_attribute)) != NULL) {
 				if (xmlStrcmp(str1, (xmlChar *)"rss") == 0) {
 					if ((str2 = xmlGetProp(cur_node, (xmlChar *)"xmlUrl")) != NULL) {
-						/* we add 1st one UNSELECTED_URL_CHAR */
+						/* We add 1st one UNSELECTED_URL_CHAR */
 						opml_str_global = l_str_cat(opml_str_global, UNSELECTED_URL_STR);
 						unesc_str = g_uri_unescape_string((const char *)str2, NULL);
 						opml_str_global = l_str_cat(opml_str_global, (const char*)unesc_str);
-						/* get feed title from feed url - ok like that? */
+						/* get feed title from feed url - OK like that? */
 						str_n_cpy(tmp_url, unesc_str, FILE_NAME_MAXLEN);
-/* TODO: double-check following 2 lines hack */
 						if (fetch_resource(tmp_url, get_datafile_full_name_from_name(TMP1),
 								tmp_url) == OK)
 							if (get_feed_info(get_datafile_full_name_from_name(TMP1),
@@ -239,8 +217,8 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 								}
 						opml_str_global = l_str_cat(opml_str_global, "\n");
 						inc_feed_counter();
-						snprintf(tmp_str, 256, "%d feeds imported so far, please wait...",
-							*get_feed_counter());
+						snprintf(tmp_str, 256, "%d feed%s imported so far, please wait...",
+							*get_feed_counter(), *get_feed_counter() <= 1 ? "" : "s");
 						win_with_progress_bar(WIN_WITH_PROGRESS_BAR_PULSE, tmp_str);
 						g_free(unesc_str);
 						xmlFree(str2);
@@ -254,7 +232,7 @@ void get_opml_selected_element(xmlNode *some_node, const char *selected_element,
 }
 
 /*
- * exporting
+ * Exporting
  */
 void export_opml_file()
 {
@@ -269,7 +247,7 @@ void export_opml_file()
 	}
 }
 
-/* must l_str_free() opml_str afterwards */
+/* Must l_str_free() opml_str afterwards */
 char *create_opml_str_from_feed_list_node(FList *node)
 {
 #define OPML_TITLE	APP_NAME"-"APP_VERSION_NUMBER" Feed List"
@@ -319,7 +297,9 @@ int save_str_as_opml_file(const char *str)
 
 	dialog = gtk_file_chooser_dialog_new("Export Feed List (OPML)", GTK_WINDOW(get_ticker_env()->win),
 			GTK_FILE_CHOOSER_ACTION_SAVE,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			/* esc_key_pressed() and force_quit_dialog() in ticker_otherwins.c return
+			 * GTK_RESPONSE_CLOSE so we must use it here instead of GTK_RESPONSE_CANCEL */
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CLOSE,
 			GTK_STOCK_OK, GTK_RESPONSE_OK,
 			NULL);
 
@@ -350,11 +330,10 @@ int save_str_as_opml_file(const char *str)
 	if (exit_status == OK) {
 		snprintf(tmp, TMPSTR_SIZE + 1,
 			"\nFeed list has been exported to OPML file: %s\n", file_name);
-		info_win(APP_NAME, tmp, INFO, FALSE);
+		info_win("", tmp, INFO, FALSE);
 	}
 	if (file_name != NULL)
 			g_free(file_name);
 	check_main_win_always_on_top();
 	return exit_status;
 }
-#endif
