@@ -18,23 +18,24 @@
 
 #include "tickr.h"
 
-#if USE_GUI
-static gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event)
+/* The 2 followings funcs always return GTK_RESPONSE_CLOSE, although
+ * sometimes GTK_RESPONSE_CANCEL would be more appropriate. */
+gint esc_key_pressed(GtkWidget *dialog2, GdkEventKey *event_key)
 {
-	if (event->keyval == GDK_Escape) {
+	if (event_key->keyval == GDK_Escape) {
 		gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CLOSE);
 		return TRUE;
 	} else
 		return FALSE;
 }
 
-static void force_quit_dialog(GtkWidget *dialog2)
+void force_quit_dialog(GtkWidget *dialog2)
 {
 	gtk_dialog_response(GTK_DIALOG(dialog2), GTK_RESPONSE_CLOSE);
 }
 
 /*
- * pick new file dialog win
+ * 'Pick new file' dialog win
  */
 void open_new_txt_file(Resource *resrc)
 {
@@ -62,7 +63,7 @@ void open_new_txt_file(Resource *resrc)
 
 	gtk_widget_show_all(dialog);
 	/*
-	 * backup last valid opened resource (if any)
+	 * Backup last valid opened resource (if any)
 	 */
 	str_n_cpy(resrc_bak.id, resrc->id, FILE_NAME_MAXLEN);
 
@@ -77,7 +78,7 @@ void open_new_txt_file(Resource *resrc)
 			break;
 		} else {
 			snprintf(tmp, TMPSTR_SIZE + 1, "load_resource() error %d", resource_flag);
-			info_win(APP_NAME" - Error", tmp, INFO_ERROR, FALSE);
+			info_win("", tmp, INFO_ERROR, FALSE);
 			str_n_cpy(resrc->id, resrc_bak.id, FILE_NAME_MAXLEN);
 			get_ticker_env()->selection_mode = selection_mode_bak;
 			load_resource(resrc, NULL);
@@ -105,8 +106,8 @@ void help_win()
 #else
 # define FONT			"Courier New 8"
 #endif
-#define HLPWIN_FG_COLOR		"#000000ff"	/* black */
-#define HLPWIN_BG_COLOR		"#ffffffff"	/* white */
+#define HLPWIN_FG_COLOR		"#000000ff"	/* Black */
+#define HLPWIN_BG_COLOR		"#ffffffff"	/* White */
 
 	GtkWidget		*dialog, *sc_win, *view;
 	GtkTextBuffer		*buf;
@@ -120,7 +121,7 @@ void help_win()
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 	dialog = gtk_dialog_new_with_buttons(
-			APP_NAME" Quick Help", GTK_WINDOW(get_ticker_env()->win),
+			"Quick Help", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
@@ -149,16 +150,16 @@ void help_win()
 	get_gdk_color_from_hexstr(HLPWIN_FG_COLOR, &fg_color, &fgc_alpha);
 	get_gdk_color_from_hexstr(HLPWIN_BG_COLOR, &bg_color, &bgc_alpha);
 	/*
-	 * not using gtk_widget_modify_fg/bg() but gtk_widget_modify_text/base()
-	 * because it's specifically for editable text
+	 * Not using gtk_widget_modify_fg/bg() but gtk_widget_modify_text/base()
+	 * because it's specifically for editable text.
 	 */
-	if (FALSE) {	/* one possible extra setting = 'same colors as ticker's' = 'yes' */
+	if (FALSE) {	/* One possible extra setting = 'same colors as ticker's' = 'yes' */
 		gtk_widget_modify_text(view, GTK_STATE_NORMAL, &(get_params()->fg_color));
 		gtk_widget_modify_base(view, GTK_STATE_NORMAL, &(get_params()->bg_color));
-	} else if (TRUE) { /* widget-level-defined */
+	} else if (TRUE) { /* Widget-level-defined */
 		gtk_widget_modify_text(view, GTK_STATE_NORMAL, &fg_color);
 		gtk_widget_modify_base(view, GTK_STATE_NORMAL, &bg_color);
-	} else if (FALSE) { /* same as label inside window */
+	} else if (FALSE) { /* Same as label inside window */
 		gtk_widget_modify_text(view, GTK_STATE_NORMAL,
 			(const GdkColor *)&(gtk_widget_get_style(get_ticker_env()->win)->fg[GTK_STATE_NORMAL]));
 		gtk_widget_modify_base(view, GTK_STATE_NORMAL,
@@ -202,7 +203,7 @@ static gint license_win()
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
 	dialog = gtk_dialog_new_with_buttons(
-			APP_NAME" License", GTK_WINDOW(get_ticker_env()->win),
+			"License", GTK_WINDOW(get_ticker_env()->win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 			NULL);
@@ -210,6 +211,7 @@ static gint license_win()
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_container_set_border_width(GTK_CONTAINER(dialog), 15);
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_NONE);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
 	g_signal_connect(G_OBJECT(dialog), "delete_event", G_CALLBACK(force_quit_dialog), NULL);
@@ -245,7 +247,6 @@ void about_win()
 {
 	GtkWidget	*dialog, *table, *image = NULL, *label[4];
 	GtkWidget	*license_but, *close_but;
-	gint		response;
 
 	gtk_window_set_keep_above(GTK_WINDOW(get_ticker_env()->win), FALSE);
 
@@ -256,16 +257,17 @@ void about_win()
 
 	license_but = gtk_dialog_add_button(GTK_DIALOG(dialog), "License", GTK_RESPONSE_NONE);
 	close_but = gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-	close_but = close_but;	/* to get rid of one compiler warning */
+	close_but = close_but;	/* to Get rid of one stupid compiler warning */
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 
 	g_signal_connect(G_OBJECT(license_but), "clicked", G_CALLBACK(license_win), NULL);
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
 	g_signal_connect(G_OBJECT(dialog), "delete_event", G_CALLBACK(force_quit_dialog), NULL);
 
-	table = gtk_table_new(7, 1, FALSE);
+	table = gtk_table_new(5, 1, FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 5);
 	gtk_container_set_border_width(GTK_CONTAINER(table), 15);
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
@@ -279,24 +281,28 @@ void about_win()
 	label[1] = gtk_label_new("<small>Copyright (C) Emmanuel Thomas-Maurin 2009-2012</small>");
 	gtk_label_set_use_markup(GTK_LABEL(label[1]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[1], 0, 1, 2, 3);
-	label[2] = gtk_label_new("<a href=\"mailto:"APP_SUPPORT_EMAIL"\">"APP_SUPPORT_EMAIL"</a>");
+	label[2] = gtk_label_new("<a href=\"mailto:"SUPPORT_EMAIL_ADDR"\">"SUPPORT_EMAIL_ADDR"</a>");
 	gtk_label_set_use_markup(GTK_LABEL(label[2]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[2], 0, 1, 3, 4);
-	label[3] = gtk_label_new("<a href=\""APP_WEBSITE"\">"APP_WEBSITE"</a>");
+	label[3] = gtk_label_new("<a href=\""WEBSITE_URL"\">"WEBSITE_URL"</a>");
 	gtk_label_set_use_markup(GTK_LABEL(label[3]), TRUE);
 	gtk_table_attach_defaults(GTK_TABLE(table), label[3], 0, 1, 4, 5);
 
 	gtk_widget_show_all(dialog);
-	while ((response = gtk_dialog_run(GTK_DIALOG(dialog))) != GTK_RESPONSE_CLOSE && \
-		response != GTK_RESPONSE_CLOSE);
+	while (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CLOSE);
 
 	gtk_widget_destroy(dialog);
 	check_main_win_always_on_top();
 }
 
 /*
- * info, warning or error
- * === should format text in case it's a long string ===
+ * Info, warning or error.
+ * ====================================================================
+ * get_params()->disable_popups applies to info_win(), info_win_wait()
+ * and warning().
+ * warning() always send info to sdtout/stderr.
+ * ====================================================================
+ * should format text in case we have a long string ?
  */
 void info_win(const char *title, const char *txt, info_type info, gboolean selectable)
 {
@@ -315,6 +321,7 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 	gtk_window_set_keep_above(GTK_WINDOW(dialog), TRUE);
 
 	g_signal_connect(G_OBJECT(dialog), "key-press-event", G_CALLBACK(esc_key_pressed), NULL);
@@ -326,7 +333,7 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), table);
 
 	if (info == INFO) {
-		/* better without any image if info only so do nothing here */
+		/* Better without any image if info only so do nothing here */
 		/*image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);*/
 	} else if (info == INFO_WARNING) {
 		image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
@@ -337,7 +344,7 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 	}
 
 	label[0] = gtk_label_new(txt);
-	/* better if disabled
+	/* Better if disabled
 	gtk_label_set_use_markup(GTK_LABEL(label[0]), TRUE);*/
 	pango_layout_get_pixel_size(gtk_label_get_layout(GTK_LABEL(label[0])),
 		&layout_width, &layout_height);
@@ -345,7 +352,7 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 		if (layout_width > get_ticker_env()->screen_w - 60)
 			gtk_widget_set_size_request(label[0], get_ticker_env()->screen_w - 60, -1);
 	} else {
-		if (layout_width > get_ticker_env()->screen_w - 120)	/* extra 60 for image width */
+		if (layout_width > get_ticker_env()->screen_w - 120)	/* Extra 60 pixels for image width */
 			gtk_widget_set_size_request(label[0], get_ticker_env()->screen_w - 120, -1);
 	}
 	if (selectable)
@@ -361,7 +368,8 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 	check_main_win_always_on_top();
 }
 
-/* delay in ms */
+/* Don't block but show up for <delay> ms then close.
+ * TODO: write a more configurable func ? */
 void info_win_wait(const char *txt, int delay)
 {
 	GtkWidget	*win;
@@ -387,7 +395,7 @@ void info_win_wait(const char *txt, int delay)
 	gtk_table_attach_defaults(GTK_TABLE(table), image, 0, 1, 0, 1);
 
 	label[0] = gtk_label_new(txt);
-	/* better if disabled
+	/* Better if disabled
 	gtk_label_set_use_markup(GTK_LABEL(label[0]), TRUE);*/
 	pango_layout_get_pixel_size(gtk_label_get_layout(GTK_LABEL(label[0])),
 		&layout_width, &layout_height);
@@ -398,7 +406,7 @@ void info_win_wait(const char *txt, int delay)
 	gtk_table_attach_defaults(GTK_TABLE(table), label[1], 2, 3, 0, 1);
 
 	gtk_widget_show_all(win);
-	/* so that win will popup immediately */
+	/* So that win will popup immediately */
 	while (gtk_events_pending())
 		gtk_main_iteration();
 
@@ -411,7 +419,7 @@ void info_win_wait(const char *txt, int delay)
 	check_main_win_always_on_top();
 }
 
-/* win centered */
+/* Win centered */
 int question_win(const char *txt)
 {
 	return question_win_at(txt, GTK_WIN_POS_CENTER);
@@ -433,8 +441,9 @@ int question_win_at(const char *txt, int win_pos)
 
 	set_tickr_icon_to_dialog(GTK_WINDOW(dialog));
 	gtk_window_set_position(GTK_WINDOW(dialog), win_pos);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
 	gtk_window_set_keep_above(GTK_WINDOW(dialog), TRUE);
-	/* why always no?
+	/* Why always no ?
 	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_NO);*/
 
 	table = gtk_table_new(1, 3, FALSE);
@@ -458,7 +467,7 @@ int question_win_at(const char *txt, int win_pos)
 	return ((response == GTK_RESPONSE_YES) ? YES : NO);
 }
 
-/* this one is buggy as the spinner don't always spin as expected (hmm...) */
+/* This one is buggy as the spinner don't always spin as expected (hmm...) */
 void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 {
 	static GtkWidget	*win;
@@ -496,7 +505,7 @@ void win_with_spinner(win_with_spinner_mode mode, const char *txt)
 		gtk_container_set_border_width(GTK_CONTAINER(GTK_BOX(hbox)), 15);
 
 		gtk_widget_show_all(win);
-		/* so that win will popup immediately */
+		/* So that win will popup immediately */
 		while (gtk_events_pending())
 			gtk_main_iteration();
 #ifndef G_OS_WIN32
@@ -539,7 +548,7 @@ void win_with_progress_bar(win_with_progress_bar_mode mode, const char *txt)
 
 		gtk_widget_show_all(win);
 
-		/* so that win will popup immediately */
+		/* So that win will popup immediately */
 		while (gtk_events_pending())
 			gtk_main_iteration();
 	} else if (mode == WIN_WITH_PROGRESS_BAR_PULSE) {
@@ -555,4 +564,3 @@ void win_with_progress_bar(win_with_progress_bar_mode mode, const char *txt)
 	} else
 		warning(FALSE, 1, "win_with_spinner(): Invalid mode");
 }
-#endif
