@@ -18,10 +18,6 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
 void set_default_options(Params *prm)
 {
 	char	tmp_font[FONT_MAXLEN + 1];
@@ -36,7 +32,7 @@ void set_default_options(Params *prm)
 
 	prm->win_x = WIN_X;
 	prm->win_y = WIN_Y;
-	prm->win_w = get_ticker_env()->screen_w;	/* instead of WIN_W; */
+	prm->win_w = get_ticker_env()->screen_w;	/* Instead of WIN_W; */
 	prm->win_h = WIN_H;
 
 	prm->windec = WINDEC;
@@ -54,14 +50,19 @@ void set_default_options(Params *prm)
 	str_n_cpy(prm->line_delimiter, LINEDELIMITER, DELIMITER_MAXLEN);
 	str_n_cpy(prm->cutline_delimiter, CUTLINEDELIMITER, DELIMITER_MAXLEN);
 
+	prm->special_chars = SPECIALCHARS;
+	prm->new_page_char = NEWPG;
+	prm->tab_char = TABCH;
+
 	prm->rss_refresh = RSSREFRESH;
-	prm->rss_title = RSSTITLE;
-	str_n_cpy(prm->rss_title_delimiter, RSSTITLEDELIMITER, DELIMITER_MAXLEN);
-	prm->rss_description = RSSDESCRIPTION;
-	str_n_cpy(prm->rss_description_delimiter, RSSDESCRIPTIONDELIMITER, DELIMITER_MAXLEN);
+	prm->feed_title = FEEDTITLE;
+	str_n_cpy(prm->feed_title_delimiter, FEEDTITLEDELIMITER, DELIMITER_MAXLEN);
+	prm->item_title = ITEMTITLE;
+	str_n_cpy(prm->item_title_delimiter, ITEMTITLEDELIMITER, DELIMITER_MAXLEN);
+	prm->item_description = ITEMDESCRIPTION;
+	str_n_cpy(prm->item_description_delimiter, ITEMDESCRIPTIONDELIMITER, DELIMITER_MAXLEN);
 
 	prm->n_items_per_feed = NITEMSPERFEED;
-	/*prm->read_in_loop = READINLOOP;*/
 	prm->strip_html_tags = STRIPHTMLTAGS;
 	prm->upper_case_text = UPPERCASETEXT;
 	str_n_cpy(prm->homefeed, HOMEFEED, FILE_NAME_MAXLEN);
@@ -79,12 +80,9 @@ void set_default_options(Params *prm)
 
 	prm->disable_popups = DISABLEPOPUPS;
 	prm->pause_on_mouseover = PAUSEONMOUSEOVER;
+	prm->disable_leftclick = DISABLELEFTCLICK;
 	prm->mouse_wheel_scroll = MOUSEWHEELSCROLL;
 
-	prm->special_chars = SPECIALCHARS;
-	prm->new_page_char = NEWPG;
-	prm->tab_char = TABCH;
-
 	prm->use_authentication = USEAUTHENTICATION;
 	str_n_cpy(prm->user, USER, USER_MAXLEN);
 	prm->use_proxy = USEPROXY;
@@ -95,9 +93,9 @@ void set_default_options(Params *prm)
 }
 
 /*
- * load conf file if any & set up - returns 0 if ok
- * store options in a string array and initialize a ptr arrays that matches strings
- * we assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each
+ * Load config file if any & set up - returns 0 if OK.
+ * Store options in a string array and initialize a ptr arrays that matches strings.
+ * We assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each.
  */
 int get_config_file_options(Params *prm)
 {
@@ -108,11 +106,11 @@ int get_config_file_options(Params *prm)
 
 	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "rb")) != NULL) {
 		/*
-		 * parse conf file
+		 * Parse config file
 		 */
 		for (i = 0; ; i++) {
 			/*
-			 * here fgets() read OPTION_MAXLEN + 1 char max including
+			 * Here fgets() read OPTION_MAXLEN + 1 char max including
 			 * '\n' then add '\0' (if I'm right...)
 			 */
 			if (i >= N_OPTION_MAX) {
@@ -128,8 +126,8 @@ int get_config_file_options(Params *prm)
 				break;
 			} else {
 				j = strlen(options_array[i]);
-				options_array[i][j - 1] = '\0';	/* we remove trailing '\n' */
-				ptr[i] = options_array[i];	/* so now options max length = OPTION_MAXLEN */
+				options_array[i][j - 1] = '\0';	/* We remove trailing '\n' */
+				ptr[i] = options_array[i];	/* so now options max length = OPTION_MAXLEN. */
 			}
 		}
 		if (i > 0)
@@ -144,8 +142,8 @@ int get_config_file_options(Params *prm)
 }
 
 /*
- * options array parser (NULL terminated ptrs array)
- * we assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each
+ * Options array parser (NULL terminated ptrs array).
+ * We assume we have up to N_OPTION_MAX options, OPTION_MAXLEN char long max each.
  */
 int parse_options_array(Params *prm, int n_options, const char *option[])
 {
@@ -167,13 +165,13 @@ int parse_options_array(Params *prm, int n_options, const char *option[])
 int get_name_value_from_option(Params *prm, const char *option)
 {
 	/*
-	 * options are splitted into name and value
+	 * Options are splitted into name and value.
 	 * font -> fname is FONT_NAME_MAXLEN char max long, fsize FONT_SIZE_MAXLEN,
 	 * plus 1 extra space so font_n_s (font name size) is up to
-	 * FONT_MAXLEN = FONT_NAME_MAXLEN + 1 + FONT_SIZE_MAXLEN char long
-	 * OPTION_MAXLEN = OPTION_NAME_MAXLEN + OPTION_VALUE_MAXLEN + 4 (-name="value")
+	 * FONT_MAXLEN = FONT_NAME_MAXLEN + 1 + FONT_SIZE_MAXLEN char long.
+	 * OPTION_MAXLEN = OPTION_NAME_MAXLEN + OPTION_VALUE_MAXLEN + 4 (-name="value").
 	 *
-	 * === if unsure, check this in tickr.h ===
+	 * === If unsure, check this in tickr.h ===
 	 */
 	char	name[OPTION_NAME_MAXLEN + 1], value[OPTION_VALUE_MAXLEN + 1];
 	char	fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
@@ -185,7 +183,7 @@ int get_name_value_from_option(Params *prm, const char *option)
 	split_font(prm->font_n_s, fname, fsize);
 	split_font(prm->clock_font_n_s, cfname, cfsize);
 	/*
-	 * split option into name & value if any
+	 * Split option into name & value if any
 	 */
 	name[0] = '\0';
 	value[0] = '\0';
@@ -203,7 +201,7 @@ int get_name_value_from_option(Params *prm, const char *option)
 		return (exit_status = OPTION_INVALID);
 	}
 	/*
-	 * check option name and get value if any
+	 * Check option name and get value if any
 	 */
 	if (strcmp(name, "delay") == 0)
 		prm->delay = atoi(value);
@@ -239,8 +237,8 @@ int get_name_value_from_option(Params *prm, const char *option)
 	else if (strcmp(name, "win_w") == 0)
 		prm->win_w = atoi(value);
 	/*
-	 * if win_h is set and > 0, it will override requested font size
-	 * with computed one
+	 * If win_h is set and > 0, it will override requested font size
+	 * with computed one.
 	 */
 	else if (strcmp(name, "win_h") == 0) {
 		prm->win_h = atoi(value);
@@ -259,7 +257,7 @@ int get_name_value_from_option(Params *prm, const char *option)
 		} else
 			prm->always_on_top = value[0];
 	} else if (strcmp(name, "wintransparency") == 0) {
-		/* compare int's (because less bug-prone) then set as gdouble */
+		/* Compare as integers (because less bug-prone) then set as gdouble */
 		prm->win_transparency = atoi(value);
 		if ((int)prm->win_transparency < 1) {
 			prm->win_transparency = 0.1;
@@ -290,10 +288,10 @@ int get_name_value_from_option(Params *prm, const char *option)
 		} else
 			prm->shadow = value[0];
 	}
-	/* should check value here */
+	/* Should check value here */
 	else if (strcmp(name, "shadowoffset_x") == 0)
 		prm->shadow_offset_x = atoi(value);
-	/* should check value here */
+	/* Should check value here */
 	else if (strcmp(name, "shadowoffset_y") == 0)
 		prm->shadow_offset_y = atoi(value);
 	else if (strcmp(name, "shadowfx") == 0)
@@ -302,33 +300,45 @@ int get_name_value_from_option(Params *prm, const char *option)
 		str_n_cpy(prm->line_delimiter, value, DELIMITER_MAXLEN);
 	else if (strcmp(name, "cutlinedelimiter") == 0)
 		str_n_cpy(prm->cutline_delimiter, value, DELIMITER_MAXLEN);
+	else if (strcmp(name, "specialchars") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->special_chars = value[0];
+	} else if (strcmp(name, "newpgchar") == 0)
+		prm->new_page_char = value[0];
+	else if (strcmp(name, "tabchar") == 0)
+		prm->tab_char = value[0];
 	else if (strcmp(name, "rssrefresh") == 0)
 		prm->rss_refresh = atoi(value);
-	else if (strcmp(name, "rsstitle") == 0) {
+	else if (strcmp(name, "feedtitle") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
 			exit_status = OPTION_VALUE_INVALID;
 		} else
-			prm->rss_title = value[0];
-	} else if (strcmp(name, "rsstitledelimiter") == 0)
-		str_n_cpy(prm->rss_title_delimiter, value, DELIMITER_MAXLEN);
-	else if (strcmp(name, "rssdescription") == 0) {
+			prm->feed_title = value[0];
+	} else if (strcmp(name, "feedtitledelimiter") == 0)
+		str_n_cpy(prm->feed_title_delimiter, value, DELIMITER_MAXLEN);
+	else if (strcmp(name, "itemtitle") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
 			exit_status = OPTION_VALUE_INVALID;
 		} else
-			prm->rss_description = value[0];
-	} else if (strcmp(name, "rssdescriptiondelimiter") == 0)
-		str_n_cpy(prm->rss_description_delimiter, value, DELIMITER_MAXLEN);
+			prm->item_title = value[0];
+	} else if (strcmp(name, "itemtitledelimiter") == 0)
+		str_n_cpy(prm->item_title_delimiter, value, DELIMITER_MAXLEN);
+	else if (strcmp(name, "itemdescription") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->item_description = value[0];
+	} else if (strcmp(name, "itemdescriptiondelimiter") == 0)
+		str_n_cpy(prm->item_description_delimiter, value, DELIMITER_MAXLEN);
 	else if (strcmp(name, "nitemsperfeed") == 0)
 		prm->n_items_per_feed = atoi(value);
-	/*else if (strcmp(name, "readinloop") == 0) {
-		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
-			fprintf(STD_ERR, "Invalid value: %s\n", option);
-			exit_status = OPTION_VALUE_INVALID;
-		} else
-			prm->read_in_loop = value[0];
-	}*/ else if (strcmp(name, "rmtags") == 0) {
+	else if (strcmp(name, "rmtags") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
 			exit_status = OPTION_VALUE_INVALID;
@@ -384,6 +394,12 @@ int get_name_value_from_option(Params *prm, const char *option)
 			exit_status = OPTION_VALUE_INVALID;
 		} else
 			prm->pause_on_mouseover = value[0];
+	} else if (strcmp(name, "disableleftclick") == 0) {
+		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
+			fprintf(STD_ERR, "Invalid value: %s\n", option);
+			exit_status = OPTION_VALUE_INVALID;
+		} else
+			prm->disable_leftclick = value[0];
 	} else if (strcmp(name, "mousewheelscroll") == 0) {
 		if (strcmp(value, "s") != 0 && strcmp(value, "f") != 0 \
 					&& strcmp(value, "n") != 0) {
@@ -391,18 +407,8 @@ int get_name_value_from_option(Params *prm, const char *option)
 			exit_status = OPTION_VALUE_INVALID;
 		} else
 			prm->mouse_wheel_scroll = value[0];
-	} else if (strcmp(name, "specialchars") == 0) {
-		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
-			fprintf(STD_ERR, "Invalid value: %s\n", option);
-			exit_status = OPTION_VALUE_INVALID;
-		} else
-			prm->special_chars = value[0];
-	} else if (strcmp(name, "newpgchar") == 0)
-		prm->new_page_char = value[0];
-	else if (strcmp(name, "tabchar") == 0)
-		prm->tab_char = value[0];
-	/* params in connection settings win */
-	else if (strcmp(name, "useauth") == 0) {
+	/* Params in connection settings win */
+	} else if (strcmp(name, "useauth") == 0) {
 		if (strcmp(value, "y") != 0 && strcmp(value, "n") != 0) {
 			fprintf(STD_ERR, "Invalid value: %s\n", option);
 			exit_status = OPTION_VALUE_INVALID;
@@ -413,7 +419,7 @@ int get_name_value_from_option(Params *prm, const char *option)
 	} else if (strcmp(name, "user") == 0) {
 		str_n_cpy(prm->user, value, USER_MAXLEN);
 		str_n_cpy(get_http_auth_user(), value, USER_MAXLEN);
-	/* this option is never saved */
+	/* This option is never saved */
 	} else if (strcmp(name, "psw") == 0)
 		str_n_cpy(get_http_auth_psw(), value, PSW_MAXLEN);
 	else if (strcmp(name, "useproxy") == 0) {
@@ -441,13 +447,16 @@ int get_name_value_from_option(Params *prm, const char *option)
 	} else if (strcmp(name, "proxyuser") == 0) {
 		str_n_cpy(prm->proxy_user, value, PROXY_USER_MAXLEN);
 		str_n_cpy(get_proxy_auth_user(), value, PROXY_USER_MAXLEN);
-	/* this option is never saved */
+	/* This option is never saved */
 	} else if (strcmp(name, "proxypsw") == 0)
 		str_n_cpy(get_proxy_auth_psw(), value, PROXY_PSW_MAXLEN);
-	/* connect params until here */
-	/* this option is only set from command line */
+	/* Connect params until here */
+	/* This option is only set from command line */
 	else if (strcmp(name, "instance-id") == 0)
-		;/* does nothing but avoid an 'unknown option' warning/error */
+		;/* Does nothing but avoid an 'unknown option' warning/error */
+	/* This option is only set from command line */
+	else if (strcmp(name, "no-ui") == 0)
+		;/* Does nothing but avoid an 'unknown option' warning/error */
 	else {
 		fprintf(STD_ERR, "Unknown option: %s\n", option);
 		exit_status = OPTION_UNKNOWN;
@@ -464,12 +473,12 @@ void save_to_config_file(const Params *prm)
 	FILE		*conf_fp;
 	char		fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
 	char		cfname[FONT_NAME_MAXLEN + 1], cfsize[FONT_SIZE_MAXLEN + 1];
-	char		tmp[2 * 1024];
+	char		tmp[4 * 1024];
 
 	if ((conf_fp = g_fopen(get_datafile_full_name_from_name(CONFIG_FILE), "wb")) != NULL) {
 		split_font(prm->font_n_s, fname, fsize);
 		split_font(prm->clock_font_n_s, cfname, cfsize);
-		snprintf(tmp, 2 * 1024, "%s%s%s",
+		snprintf(tmp, 4 * 1024, "%s%s%s",
 			"-delay=%d\n"
 			"-shiftsize=%d\n"
 			"-fontname=%s\n"
@@ -491,11 +500,16 @@ void save_to_config_file(const Params *prm)
 			"-shadowfx=%d\n"
 			"-linedelimiter=%s\n",
 			"-cutlinedelimiter=%s\n"
+			"-specialchars=%c\n"
+			"-newpgchar=%c\n"
+			"-tabchar=%c\n"
 			"-rssrefresh=%d\n"
-			"-rsstitle=%c\n"
-			"-rsstitledelimiter=%s\n"
-			"-rssdescription=%c\n"
-			"-rssdescriptiondelimiter=%s\n"
+			"-feedtitle=%c\n"
+			"-feedtitledelimiter=%s\n"
+			"-itemtitle=%c\n"
+			"-itemtitledelimiter=%s\n"
+			"-itemdescription=%c\n"
+			"-itemdescriptiondelimiter=%s\n"
 			"-nitemsperfeed=%d\n"
 			"-rmtags=%c\n"
 			"-uppercasetext=%c\n"
@@ -504,15 +518,13 @@ void save_to_config_file(const Params *prm)
 			"-openlinkargs=%s\n"
 			"-clock=%c\n"
 			"-clockfontname=%s\n"
-			"-clockfontsize=%d\n"
+			"-clockfontsize=%d\n",
 			"-clockfgcolor=%s\n"
 			"-clockbgcolor=%s\n"
 			"-disablepopups=%c\n"
 			"-pauseonmouseover=%c\n"
-			"-mousewheelscroll=%c\n",
-			"-specialchars=%c\n"
-			"-newpgchar=%c\n"
-			"-tabchar=%c\n"
+			"-disableleftclick=%c\n"
+			"-mousewheelscroll=%c\n"
 			"-useauth=%c\n"
 			"-user=%s\n"
 			"-useproxy=%c\n"
@@ -542,11 +554,16 @@ void save_to_config_file(const Params *prm)
 			prm->shadow_fx,
 			prm->line_delimiter,
 			prm->cutline_delimiter,
+			prm->special_chars,
+			prm->new_page_char,
+			prm->tab_char,
 			prm->rss_refresh,
-			prm->rss_title,
-			prm->rss_title_delimiter,
-			prm->rss_description,
-			prm->rss_description_delimiter,
+			prm->feed_title,
+			prm->feed_title_delimiter,
+			prm->item_title,
+			prm->item_title_delimiter,
+			prm->item_description,
+			prm->item_description_delimiter,
 			prm->n_items_per_feed,
 			prm->strip_html_tags,
 			prm->upper_case_text,
@@ -560,10 +577,8 @@ void save_to_config_file(const Params *prm)
 			get_hexstr_from_gdk_color(&prm->clock_bg_color, &prm->clock_bg_color_alpha),
 			prm->disable_popups,
 			prm->pause_on_mouseover,
+			prm->disable_leftclick,
 			prm->mouse_wheel_scroll,
-			prm->special_chars,
-			prm->new_page_char,
-			prm->tab_char,
 			prm->use_authentication,
 			prm->user,
 			prm->use_proxy,
@@ -580,7 +595,7 @@ void save_to_config_file(const Params *prm)
 }
 
 /*
- * options colors are coded as 4 hexa values -> #rrggbbaa
+ * Options colors are coded as 4 hexa values -> #rrggbbaa
  */
 int get_gdk_color_from_hexstr(const char *str, GdkColor *color, guint16 *color_alpha)
 {
@@ -618,7 +633,7 @@ int get_gdk_color_from_hexstr(const char *str, GdkColor *color, guint16 *color_a
 }
 
 /*
- * options colors are coded as 4 hexa values -> #rrggbbaa
+ * Options colors are coded as 4 hexa values -> #rrggbbaa
  * *** allow up to 64 simultaneous calls ***
  */
 const char *get_hexstr_from_gdk_color(const GdkColor *color, const guint16 *color_alpha)
@@ -637,7 +652,7 @@ const char *get_hexstr_from_gdk_color(const GdkColor *color, const guint16 *colo
 }
 
 /*
- * space needed for font_name: FONT_NAME_MAXLEN + 1 bytes / font_size: FONT_SIZE_MAXLEN + 1 bytes
+ * Space needed for font_name: FONT_NAME_MAXLEN + 1 bytes / font_size: FONT_SIZE_MAXLEN + 1 bytes
  */
 void split_font(const char *font_name_size, char *font_name, char *font_size)
 {
@@ -660,7 +675,7 @@ void split_font(const char *font_name_size, char *font_name, char *font_size)
 }
 
 /*
- * space needed for font_name_size: FONT_NAME_MAXLEN + 1 space + FONTSIZENMAXLEN + 1 bytes
+ * Space needed for font_name_size: FONT_NAME_MAXLEN + 1 space + FONTSIZENMAXLEN + 1 bytes
  */
 void compact_font(char *font_name_size, const char *font_name, const char *font_size)
 {
