@@ -18,24 +18,18 @@
 
 #include "tickr.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
 /*
- * NEW STUFF: set env->stream_fully_read flag
- *
- * render n lines of a stream (opened text file) into an image (cairo surface)
- * of one long single line of text
- * - one single stream is likely to be splitted into several text parts
+ * Render n lines of a stream (opened text file) into an image (cairo surface)
+ * of one long single line of text.
+ * - One single stream is likely to be splitted into several text parts.
  * - n is limited because surface width must be <= (XPIXMAP_MAXWIDTH = 32 K - 1)
  * (DO THIS STILL APPLY TO CAIRO IMAGE SURFACES ?)
- * - return adr of newly created surface
- * if returned surface is NULL then render_exit_status is set accordingly and
+ * - Return addr of newly created surface.
+ * If returned surface is NULL then render_exit_status is set accordingly and
  * should be checked to know which error occured
  * (otherwise render_exit_status = OK or RENDER_NO_RESOURCE or
- * RENDER_LINE_TOO_LONG)
- * LINE_MAXLEN should be set to ensure that we won't have lines too long
+ * RENDER_LINE_TOO_LONG).
+ * LINE_MAXLEN should be set to ensure that we won't have too-long lines.
  */
 cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_offset, const Params *prm, \
 		int *render_exit_status)
@@ -53,7 +47,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	*render_exit_status = OK;
 	env->stream_fully_read = FALSE;
 	/*
-	 * create layout
+	 * Create layout
 	 */
 	p_layout = pango_layout_new(gtk_widget_get_pango_context(env->win));
 	pango_layout_set_attributes(p_layout, NULL);
@@ -64,7 +58,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	pango_font_description_free(f_des);
 	pango_layout_context_changed(p_layout);
 	/*
-	 * get text string from stream
+	 * Get text string from stream
 	 */
 	txt_str = l_str_new(NULL);
 
@@ -79,15 +73,15 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 		*render_exit_status = RENDER_NO_RESOURCE;
 	}
 	/*
-	 * translate link ranks inside (eventually splitted) text into offsets in surface
+	 * Translate link ranks inside (eventually splitted) text into offsets in surface.
 	 *
-	 * scan text for "<LINK_TAG_CHAR>00n" and get
+	 * Scan text for "<LINK_TAG_CHAR>00n" and get
 	 * offset = layout_width(< text from start to tag >),
 	 * for every rss item found
 	 * then remove tags and fill an array of FeedLinkAndOffset's
-	 * with offsets (rank and url variables are already filled)
+	 * with offsets (rank and url variables are already filled).
 	 */
-	for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++)	/* we reset all offsets to 0 */
+	for (i = 0; i < NFEEDLINKANDOFFSETMAX; i++)	/* We reset all offsets to 0 */
 		(link_and_offset + i)->offset_in_surface = 0;
 	for (i = 0; txt_str[i] != '\0'; i++) {
 		if (txt_str[i] == LINK_TAG_CHAR) {
@@ -100,7 +94,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 		}
 	}
 	/*
-	 * fill layout
+	 * Fill layout
 	 */
 	pango_layout_set_text(p_layout, txt_str, -1);
 	l_str_free(txt_str);
@@ -114,7 +108,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 		return NULL;
 	}
 	/*
-	 * create cairo image surface onto which layout will be rendered
+	 * Create cairo image surface onto which layout will be rendered
 	 */
 	env->c_surf = cairo_image_surface_create(CAIRO_FORMAT_ARGB32,
 		env->surf_width, env->surf_height);
@@ -125,10 +119,10 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	}
 	cr = cairo_create(env->c_surf);
 	/*
-	 * render layout
-	 * (are used cairo operators ok ?)
+	 * Render layout
+	 * (are used cairo operators OK ?)
 	 */
-	/* draw background */
+	/* Draw background */
 	cairo_set_source_rgba(cr,
 		(float)prm->bg_color.red / G_MAXUINT16,
 		(float)prm->bg_color.green / G_MAXUINT16,
@@ -137,9 +131,9 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 		);
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_paint(cr);
-	/* draw foreground */
+	/* Draw foreground */
 	if (prm->shadow == 'y') {
-		/* draw shadow */
+		/* Draw shadow */
 		if (prm->shadow_fx < 0)
 			shadow_k = 1.0;
 		else if (prm->shadow_fx > 10)
@@ -156,7 +150,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 		cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 		pango_cairo_show_layout(cr, p_layout);
 	}
-	/* draw text */
+	/* Draw text */
 	cairo_set_source_rgba(cr,
 		(float)prm->fg_color.red / G_MAXUINT16,
 		(float)prm->fg_color.green / G_MAXUINT16,
@@ -166,7 +160,7 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 	cairo_move_to(cr, 0, 0);
 	cairo_set_operator(cr, CAIRO_OPERATOR_OVER);
 	pango_cairo_show_layout(cr, p_layout);
-	/* drawing done - return surface */
+	/* Drawing done - return surface */
 	if (p_layout != NULL)
 		g_object_unref(p_layout);
 	cairo_destroy(cr);
@@ -174,10 +168,10 @@ cairo_surface_t *render_stream_to_surface(FILE *fp, FeedLinkAndOffset *link_and_
 }
 
 /*
- * split stream into a a set of long lines so that, after rendering of each one,
- * we get a cairo image surface whose width is <= (XPIXMAP_MAXWIDTH = 32 K - 1)
- * if one line is longer than tmp2_size, it's truncated and CUTLINE_DELIMITER is
- * appended but we should make sure that this won't happen
+ * Split stream into a a set of long lines so that, after rendering of each one,
+ * we get a cairo image surface whose width is <= (XPIXMAP_MAXWIDTH = 32 K - 1).
+ * If one line is longer than tmp2_size, it will get truncated and CUTLINE_DELIMITER
+ * will be appended but we should make sure that this will not happen.
  */
 char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Params *prm, int *render_exit_status)
 {
@@ -186,11 +180,11 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 	static char	*ending_str = NULL;
 	long int	file_pos;
 	char		*tmp1, *tmp2;
-	size_t		tmp1_size = LINE_MAXLEN * 4;	/* anyways, this is adjusted by getline() */
-	size_t		tmp2_size =  64 * 1024;		/* this should always be enough */
+	size_t		tmp1_size = LINE_MAXLEN * 4;	/* Anyways, this is adjusted by getline() */
+	size_t		tmp2_size =  64 * 1024;		/* This should always be enough (hmmm...) */
 	int		c = 0;
 	char		*empty_line;
-	int		empty_line_length, empty_line_width, txt_str_width;/* len in char, width in pixels */
+	int		empty_line_length, empty_line_width, txt_str_width;/* Length in chars, width in pixels */
 	int		i, j, k;
 #ifndef G_OS_WIN32
 	ssize_t		n;
@@ -198,7 +192,7 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 
 	*render_exit_status = OK;
 	/*
-	 * creating an "empty line"
+	 * Creating an "empty line"
 	 */
 	empty_line = l_str_new(NULL);
 	do
@@ -208,7 +202,7 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 	if (env->reload_rq)
 		text_splitted = FALSE;
 	/*
-	 * we start with an "empty line" but if text has been splitted
+	 * We start with an "empty line" but if text has been splitted.
 	 */
 	if (!text_splitted) {
 		txt_str = l_str_cat(txt_str, empty_line);
@@ -228,19 +222,17 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 	}
 	text_splitted = FALSE;
 	/*
-	 * then we read stream (text file) into txt_str one line at a time
-	 * text file has previously been formatted with extra newline's so that
-	 * no line is longer than LINE_MAXLEN
-	 * we must make sure that no line needs to be cut (width > (XPIXMAP_MAXWIDTH = 32 K - 1)
-	 * after rendering) but how do we set LINE_MAXLEN properly?
+	 * Then we read stream (text file) into txt_str, one line at a time.
+	 * Text file has been previously formatted with extra newline's so that
+	 * no line is longer than LINE_MAXLEN.
+	 * We must make sure that no line needs to be cut (width > (XPIXMAP_MAXWIDTH = 32 K - 1)
+	 * after rendering) but how do we set LINE_MAXLEN properly ?
 	 * LINE_MAXLEN < (XPIXMAP_MAXWIDTH = 32 K - 1) / FONT_MAXSIZE = about 163 if maxsize = 200
-	 * so 128 should be always ok (see tickr.h)
+	 * so 128 should always be OK (see tickr.h)
 	 *
-	 * ============================================================================
-	 * it would be much better, for performance reasons, to replace
-	 * LINE_MAXLEN by a variable like: line_maxlen = k * XPIXMAP_MAXWIDTH / font_size
-	 * especially when font_size is big
-	 * ============================================================================
+	 * (It could be better, for performance reasons, to replace LINE_MAXLEN
+	 * by a variable like: line_maxlen = k * XPIXMAP_MAXWIDTH / font_size,
+	 * especially when font_size is big.)
 	 */
 	tmp1 = malloc2((tmp1_size + 1) * sizeof(char));	/* tmp1 will get 1 line */
 	tmp2 = malloc2((tmp2_size + 1) * sizeof(char));	/* tmp2 will get 1 "expanded" line */
@@ -255,14 +247,14 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 		if (fgets(tmp1, tmp1_size, fp) == NULL) {
 #endif
 			/*
-			 * eof or error?
+			 * eof or error ?
 			 */
 			if (feof(fp) == 0) {
 				*render_exit_status = RENDER_GETLINE_ERROR;
 				return txt_str;
 			}
 			/*
-			 * text file fully read
+			 * Text file fully read
 			 * -> reset to beginning in single selection mode
 			 * or
 			 * -> set flag so that to load next feed in multiple selection mode
@@ -279,7 +271,7 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 			for (i = 0, j = 0; i < (int)strlen(tmp1); i++) {
 #endif
 				/*
-				 * this is not supposed to happen but if tmp2_size was wrongly set
+				 * This is not supposed to happen but if tmp2_size was wrongly set
 				 */
 				if ((size_t)j >= tmp2_size - strlen(prm->cutline_delimiter) - 1) {
 					str_n_cpy(&tmp2[j], prm->cutline_delimiter, OPTION_VALUE_MAXLEN);
@@ -316,8 +308,8 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 		txt_str_width += get_layout_width(p_layout, tmp2);
 		if (txt_str_width > XPIXMAP_MAXWIDTH - 2 * empty_line_width - prm->shadow_offset_x) {
 			/*
-			 * need to split text into several parts
-			 * we don't add this line but will use it in next surface
+			 * Need to split text into several parts.
+			 * We don't add this line but will use it in next surface.
 			 */
 			fseek(fp, file_pos, SEEK_SET);
 			text_splitted = TRUE;
@@ -326,14 +318,14 @@ char *stream_to_htext(FILE *fp, char *txt_str, PangoLayout *p_layout, const Para
 			txt_str = l_str_cat(txt_str, tmp2);
 	}
 	/*
-	 * and we end with an "empty line" but if text has been splitted
+	 * And we end with an "empty line" but if text has been splitted,
 	 */
 	if (!text_splitted) {
 		txt_str = l_str_cat(txt_str, empty_line);
 		ending_str = NULL;
 	} else {
 		/*
-		 * in which case we keep "tail" of txt_str whose width is drwa_width
+		 * in which case we keep "tail" of txt_str whose width is drwa_width.
 		 */
 		i = strlen(txt_str) - 1;
 		while (get_layout_width(p_layout, txt_str + i--) <= env->drwa_width);
@@ -369,7 +361,7 @@ int get_fsize_from_layout_height(gint height, const char *fontname)
 	PangoFontDescription	*f_des;
 	char			fnamesize[FONT_MAXLEN + 1];
 	char			fname[FONT_NAME_MAXLEN + 1], fsize[FONT_SIZE_MAXLEN + 1];
-	char			check_str[] = "gjpqyÀÄÅÇÉÖÜ€£$!&({[?|";	/* should be enough - is it? */
+	char			check_str[] = "gjpqyÀÄÅÇÉÖÜ€£$!&({[?|";	/* Should be enough - Is it? */
 	gint			height2;
 	int			i = 1;
 
@@ -438,7 +430,7 @@ gint get_layout_height(PangoLayout *p_layout, const char *str)
 	return (gint)layout_height;
 }
 
-/* to avoid troubles in case of an empty string inside layout */
+/* To avoid troubles in case of an empty string inside layout */
 void pango_layout_get_pixel_size2(PangoLayout *p_layout, int *layout_width, int *layout_height)
 {
 	if (strlen(pango_layout_get_text(p_layout)) > 0)
