@@ -19,15 +19,11 @@
 #include "tickr.h"
 #include "tickr_html_entities.h"
 
-#ifdef G_OS_WIN32
-extern FILE	*stdout_fp, *stderr_fp;
-#endif
-
 /*
- * build selection f_list from full feed f_list
+ * Build selection f_list from full feed f_list.
  *
- * always use get/set_feed_list() and get/set_feed_selection() to access
- * FList *feed_list and FList *feed_selection defined in tickr_main.c
+ * Always use get/set_feed_list() and get/set_feed_selection() to access
+ * FList *feed_list and FList *feed_selection defined in tickr_main.c.
  */
 int build_feed_selection_from_feed_list()
 {
@@ -55,7 +51,7 @@ int build_feed_selection_from_feed_list()
  * feed_index_in_selection starts at 0
  * (these funcs do nothing in single selection mode)
  */
-/* always reload -> ok like that ? */
+/* Always reload -> OK like that ? */
 void current_feed()
 {
 	FList	*selection = get_feed_selection();
@@ -70,7 +66,7 @@ void current_feed()
 	}
 }
 
-/* always reload -> ok like that ? */
+/* Always reload -> OK like that ? */
 void first_feed()
 {
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
@@ -79,7 +75,7 @@ void first_feed()
 	}
 }
 
-/* always reload -> ok like that ? */
+/* Always reload -> OK like that ? */
 void last_feed()
 {
 	if (get_ticker_env()->selection_mode == MULTIPLE) {
@@ -123,10 +119,10 @@ gboolean next_feed()
 }
 
 /*
- * - single mode: (re)load resrc->id = text file if it exists or rss feed if valid
- * - multiple mode: load sequentially all selected feeds in feed list
+ * - Single mode: (re)load resrc->id = text file if it exists or rss feed if valid.
+ * - Multiple mode: load sequentially all selected feeds in feed list.
  *
- * in case of url: load_resource() -> get_feed() -> parse_rss20/rss10/atom_xml_file()
+ * In case of url: load_resource() -> get_feed() -> parse_rss20/rss10/atom_xml_file().
  */
 int load_resource(Resource *resrc, FList *feed_selection)
 {
@@ -169,7 +165,7 @@ int load_resource(Resource *resrc, FList *feed_selection)
 		exit_status = RESOURCE_UNSPECIFIED;
 	} else {
 		/*
-		 * is there an existing file?
+		 * Is there an existing file ?
 		 */
 #ifndef G_OS_WIN32
 		if ((resrc->fp = g_fopen(resrc->id, "rb")) == NULL) {
@@ -179,7 +175,7 @@ int load_resource(Resource *resrc, FList *feed_selection)
 			g_free(win32_filename);
 #endif
 			/*
-			 * if not, have we a valid rss url instead?
+			 * If not, have we a valid rss url instead ?
 			 */
 			if ((rss_status = get_feed(resrc, get_params())) != OK) {
 				if (rss_status != FEED_UNPARSABLE && rss_status != FEED_EMPTY &&\
@@ -219,9 +215,10 @@ int load_resource(Resource *resrc, FList *feed_selection)
 }
 
 /*
- * strip html tags
- * then check for lines longer than LINE_MAXLEN and insert newline's if any
- * then resrc->fp refers to a "formatted" file
+ * Strip html tags,
+ * then 'translate' html entities,
+ * then check for lines longer than LINE_MAXLEN and insert newline's if any,
+ * then resrc->fp refers to a "formatted" file.
  */
 int format_resource(Resource *resrc)
 {
@@ -231,7 +228,7 @@ int format_resource(Resource *resrc)
 	int		is_inside_tag = FALSE, c, i;
 	gchar		*p;
 
-	/* strip html tags */
+	/* Strip html tags */
 	tmp_fp = open_new_datafile_with_name(TMP1, "wb+");
 	i = 0;
 	while ((c = fgetc(resrc->fp)) != (int)EOF) {
@@ -243,7 +240,7 @@ int format_resource(Resource *resrc)
 				is_inside_tag = FALSE;
 		} else
 			is_inside_tag = FALSE;
-		/* a little bit confusing here... */
+		/* A little bit confusing here... */
 		if (!is_inside_tag && !(get_params()->strip_html_tags == 'y' && c == '>'))
 			fputc((int)c, tmp_fp);
 		else if (i++ < 1)
@@ -253,7 +250,7 @@ int format_resource(Resource *resrc)
 	resrc->fp = tmp_fp;
 	fseek(resrc->fp, 0, SEEK_SET);
 
-	/* 'translate' html entities */
+	/* 'Translate' html entities */
 	tmp_fp = open_new_datafile_with_name(TMP2, "wb+");
 	while ((c = fgetc(resrc->fp)) != (int)EOF) {
 		if (c == '&') {
@@ -280,7 +277,7 @@ int format_resource(Resource *resrc)
 	resrc->fp = tmp_fp;
 	fseek(resrc->fp, 0, SEEK_SET);
 
-	/* check for lines longer than LINE_MAXLEN and insert newline's if any */
+	/* Check for lines longer than LINE_MAXLEN and insert newline's if any */
 	tmp_fp = open_new_datafile_with_name(XML_DUMP, "wb+");
 	str1 = malloc2(str1_size * sizeof(char));
 	str2 = l_str_new(NULL);
@@ -296,9 +293,9 @@ int format_resource(Resource *resrc)
 		if (*p == '\n')
 			i = 0;
 		/*
-		 * if the word we are parsing isn't longer than WORD_MAXLEN
-		 * chars, we replace the 1st ' ' found after it with a '\n'
-		 * otherwise the word is cut off
+		 * If the word we are parsing isn't longer than WORD_MAXLEN
+		 * chars, we replace the 1st ' ' found after it with '\n',
+		 * otherwise the word is cut off.
 		 */
 		if (i >= LINE_MAXLEN - WORD_MAXLEN)
 			if (i >= LINE_MAXLEN || g_unichar_isspace(*p)) {
@@ -317,15 +314,15 @@ int format_resource(Resource *resrc)
 }
 
 /*
- * *** file names, paths and dirs stuff ***
+ * *** File names, paths and dirs stuff ***
  */
 void set_tickr_icon_to_dialog(GtkWindow *dialog)
 {
 	gtk_window_set_icon_from_file(dialog, get_imagefile_full_name_from_name(TICKR_ICON), NULL);
 }
 
-/* open/create file in data dir from name
- * data dir = config files, not images files
+/* Open/create file in data dir from name.
+ * Data dir = config files, not images files.
  */
 FILE *open_new_datafile_with_name(const char *name, const char *mode_str)
 {
@@ -351,8 +348,8 @@ FILE *open_new_datafile_with_name(const char *name, const char *mode_str)
 	return fp;
 }
 
-/* get full path and name for file in data dir from name
- * data dir = config files, not images files
+/* Get full path and name for file in data dir from name.
+ * Data dir = config files, not images files.
  */
 char *get_datafile_full_name_from_name(const char *name)
 {
@@ -373,7 +370,7 @@ char *get_datafile_full_name_from_name(const char *name)
 	return file_name;
 }
 
-/* now, image files */
+/* Now, image files */
 char *get_imagefile_full_name_from_name(const char *name)
 {
 	static char	file_name[FILE_NAME_MAXLEN + 1];
@@ -394,7 +391,7 @@ char *get_imagefile_full_name_from_name(const char *name)
 	return file_name;
 }
 
-/* data dir = config files, not images files */
+/* Data dir = config files, not images files */
 char *get_datadir_full_path()
 {
 	static char	full_path[TMPSTR_SIZE + 1];
@@ -414,6 +411,6 @@ char *usr_home_dir()
 #ifndef G_OS_WIN32
 	return str_n_cpy(str, getpwuid(getuid())->pw_dir, TMPSTR_SIZE);
 #endif
-	/* for win32 version, no home dir - see win32 specific funcs in libetm */
+	/* For win32 version, no home dir - See win32 specific funcs in libetm. */
 	return str;
 }
